@@ -924,7 +924,8 @@ void RopTest(void) {
 void QixDemo(int rop, char *txt) {
     int current = 0, dx1, dy1, dx2, dy2, i, cols = 1, cx1, cx2, cy1, cy2;
     int startclock, diffclock;
-    unsigned long pixels = 0, numlines = 0;
+    unsigned long pixels = 0;
+    unsigned int  numlines = 0;
     struct {
 	unsigned short x1;	
 	unsigned short y1;	
