@@ -286,7 +286,7 @@ void speed(void)
 }
 
 
-void main(void)
+int main(void)
 {
     vga_init();
 
