@@ -7,9 +7,9 @@
   * accesses.  Instructions have been shuffled a bit for possible
   * avoidance of pipeline hazards.
   */
-void memcpy4to3(void *dest, void *src, int n)
+void __svgalib_memcpy4to3(void *dest, void *src, int n)
 {
-    printf("libgl: memcpy4to3 not done yet\n");
+    printf("libgl: __svgalib_memcpy4to3 not done yet\n");
 }
 
 /* 
@@ -17,7 +17,7 @@ void memcpy4to3(void *dest, void *src, int n)
  * 0BGR 4-byte-per-pixel screen.
  * Used by copyscreen for ATI mach32 32-bit truecolor modes.
  */
-void memcpy32shift8(void *dest, void *src, int n)
+void __svgalib_memcpy32shift8(void *dest, void *src, int n)
 {
-    printf("libgl: memcpy32shift8 not done yet\n");
+    printf("libgl: __svgalib_memcpy32shift8 not done yet\n");
 }
