@@ -9,40 +9,11 @@
 #include "vgagl.h"
 #include "def.h"
 
-
-/* #define USE_ASM */
-
-
-#ifdef __alpha__
-
-static inline int muldiv64(int m1, int m2, int d)
+static inline int muldiv64(float m1, float m2, float d)
 {
-    return (long) m1 *(long) m2 / (long) d;
+    return m1 * m2 / d;
 }
 
-#else
-
-/* We use the 32-bit to 64-bit multiply and 64-bit to 32-bit divide of the */
-/* 386 (which gcc doesn't know well enough) to efficiently perform integer */
-/* scaling without having to worry about overflows. */
-
-static inline int muldiv64(int m1, int m2, int d)
-{
-/* int32 * int32 -> int64 / int32 -> int32 */
-    int result;
-    int dummy;
-    __asm__(
-	       "imull %%edx\n\t"
-	       "idivl %4\n\t"
-  :	       "=a"(result), "=d"(dummy)	/* out */
-  :	       "0"(m1), "1"(m2), "g"(d)		/* in */
-	       /***rjr***:	       "ax", "dx"***/	/* mod */
-	);
-    return result;
-}
-
-#endif				/* !__alpha__ */
-
 /* This is a DDA-based algorithm. */
 /* Iteration over target bitmap. */
 
@@ -70,57 +41,6 @@ void gl_scalebox(int w1, int h1, void *_dp1, int w2, int h2, void *_dp2)
 		int x;
 		x = 0;
 		while (x < w2 - 8) {
-#ifdef USE_ASM
-
-		    /* This saves just a couple of cycles per */
-		    /* pixel on a 486, but I couldn't resist. */
-		    __asm__ __volatile__("movl %4, %%eax\n\t"
-					 "shrl $16, %%eax\n\t"
-					 "addl %5, %4\n\t"
-					 "movb (%3, %%eax), %%al\n\t"
-					 "movb %%al, (%1, %2)\n\t"
-					 "movl %4, %%eax\n\t"
-					 "shrl $16, %%eax\n\t"
-					 "addl %5, %4\n\t"
-					 "movb (%3, %%eax), %%al\n\t"
-					 "movb %%al, 1 (%1, %2)\n\t"
-					 "movl %4, %%eax\n\t"
-					 "shrl $16, %%eax\n\t"
-					 "addl %5, %4\n\t"
-					 "movb (%3, %%eax), %%al\n\t"
-					 "movb %%al, 2 (%1, %2)\n\t"
-					 "movl %4, %%eax\n\t"
-					 "shrl $16, %%eax\n\t"
-					 "addl %5, %4\n\t"
-					 "movb (%3, %%eax), %%al\n\t"
-					 "movb %%al, 3 (%1, %2)\n\t"
-					 "movl %4, %%eax\n\t"
-					 "shrl $16, %%eax\n\t"
-					 "addl %5, %4\n\t"
-					 "movb (%3, %%eax), %%al\n\t"
-					 "movb %%al, 4 (%1, %2)\n\t"
-					 "movl %4, %%eax\n\t"
-					 "shrl $16, %%eax\n\t"
-					 "addl %5, %4\n\t"
-					 "movb (%3, %%eax), %%al\n\t"
-					 "movb %%al, 5 (%1, %2)\n\t"
-					 "movl %4, %%eax\n\t"
-					 "shrl $16, %%eax\n\t"
-					 "addl %5, %4\n\t"
-					 "movb (%3, %%eax), %%al\n\t"
-					 "movb %%al, 6 (%1, %2)\n\t"
-					 "movl %4, %%eax\n\t"
-					 "shrl $16, %%eax\n\t"
-					 "addl %5, %4\n\t"
-					 "movb (%3, %%eax), %%al\n\t"
-					 "movb %%al, 7 (%1, %2)\n\t"
-					 :	/* output */
-					 :	/* input */
-				     "ax"(0), "r"(dp2), "r"(x), "r"(dp1),
-					 "r"(sx), "r"(xfactor)
-					 :"ax", "4"
-		    );
-#else
 		    *(dp2 + x) = *(dp1 + (sx >> 16));
 		    sx += xfactor;
 		    *(dp2 + x + 1) = *(dp1 + (sx >> 16));
@@ -137,7 +57,6 @@ void gl_scalebox(int w1, int h1, void *_dp1, int w2, int h2, void *_dp2)
 		    sx += xfactor;
 		    *(dp2 + x + 7) = *(dp1 + (sx >> 16));
 		    sx += xfactor;
-#endif
 		    x += 8;
 		}
 		while (x < w2) {
