@@ -1,8 +1,17 @@
 /* vram size in pages */
 
+#ifdef __386__
+
+#include <linux/version.h>
+#include <asm/uaccess.h>
+#include <asm/system.h>   /* cli(), *_flags */
+#include <asm/segment.h>  /* memcpy and such */
+#include <asm/io.h>
+#include <asm/pgtable.h>
+
 #define I810_SIZE 1024
 
-static unsigned long i810_alloc_page()
+unsigned long i810_alloc_page()
 {
 	unsigned long address;
 
@@ -32,10 +41,10 @@ static void i810_free_page(unsigned long page)
 #endif
 
 static unsigned long i810_pages[I810_SIZE];
-static unsigned long i810_gttes[I810_SIZE];
+unsigned long i810_gttes[I810_SIZE];
 static unsigned long i810_gttpage=0;
 
-static unsigned int i810_make_gtt() {
+unsigned int i810_make_gtt() {
 	int i;
         
         if(i810_gttpage) return virt_to_bus((void *)i810_gttpage);
@@ -53,3 +62,5 @@ static unsigned int i810_make_gtt() {
 
         return virt_to_bus((void *)i810_gttpage);
 }
+
+#endif
