@@ -25,7 +25,7 @@ typedef struct {
     void (*DAC_restoreState) (const unsigned char *regs);
     void (*DAC_initializeState) (unsigned char *regs, int bpp, int colormode,
 				 int pixelclock);
-    long TextFrequency;
+    int TextFrequency;
     int DAC_stateSize;
 } ClockChipMethods;
 
