@@ -132,7 +132,7 @@ static int ali_saveregs(unsigned char regs[])
     tmp = GETB(GRA_I, 0x0c);
     regs[EXT + 7] = port_in(0x3d6);
     regs[EXT + 8] = port_in(0x3d7);
-    outb(0x3d6, 0);
+    port_out_r(0x3d6, 0);
     regs[EXT + 0] = GETB(__svgalib_CRT_I, 0x19);
     regs[EXT + 1] = GETB(__svgalib_CRT_I, 0x1a);
     regs[EXT + 2] = GETB(__svgalib_CRT_I, 0x28);
@@ -158,9 +158,9 @@ static void ali_setregs(const unsigned char regs[], int mode)
     int tmp;
     ali_unlock();
     tmp = GETB(GRA_I, 0x0f);
-    outb(GRA_D, tmp | 4);
-    outb(0x3d6, 0);
-    outb(0x3d7, 0);
+    port_out_r(GRA_D, tmp | 4);
+    port_out_r(0x3d6, 0);
+    port_out_r(0x3d7, 0);
     SETB(__svgalib_CRT_I, 0x19, regs[EXT + 0]);
     SETB(__svgalib_CRT_I, 0x1a, regs[EXT + 1] | 0x10);	/* |0x10 to prevent locking */
     SETB(GRA_I, 0x0b, regs[EXT + 4]);
@@ -172,9 +172,9 @@ static void ali_setregs(const unsigned char regs[], int mode)
     port_in(0x3c6);
     port_in(0x3c6);
     port_in(0x3c6);
-    outb(0x3c6, regs[EXT + 6]);
-    outb(0x3d6, regs[EXT + 7]);
-    outb(0x3d7, regs[EXT + 8]);
+    port_out_r(0x3c6, regs[EXT + 6]);
+    port_out_r(0x3d6, regs[EXT + 7]);
+    port_out_r(0x3d7, regs[EXT + 8]);
 }
 
 /* ali_modeavailable( int mode )                        Check if mode supported
@@ -246,10 +246,10 @@ static void ali_unlock(void)
 {
     int temp;
     temp = GETB(__svgalib_CRT_I, 0x1a);
-    outb(__svgalib_CRT_D, temp | 0x10);
+    port_out_r(__svgalib_CRT_D, temp | 0x10);
     /* Unprotect CRTC[0-7] */
     temp = GETB(__svgalib_CRT_I, 0x11);
-    outb(__svgalib_CRT_D, temp & 0x7f);
+    port_out_r(__svgalib_CRT_D, temp & 0x7f);
 
 }
 
@@ -264,9 +264,9 @@ static void ali_lock(void)
     int tmp;
     /* Protect CRTC[0-7] */
     tmp = GETB(__svgalib_CRT_I, 0x11);
-    outb(__svgalib_CRT_D, tmp | 0x80);
+    port_out_r(__svgalib_CRT_D, tmp | 0x80);
     tmp = GETB(__svgalib_CRT_I, 0x1a);
-    outb(__svgalib_CRT_D, tmp & 0xef);
+    port_out_r(__svgalib_CRT_D, tmp & 0xef);
 }
 
 static int cwg(void)
@@ -276,10 +276,10 @@ static int cwg(void)
     t = port_in(GRA_I);
     t1 = GETB(GRA_I, 0x0b);
     t2 = t1 & 0x30;
-    outb(GRA_D, t2 ^ 0x30);
+    port_out_r(GRA_D, t2 ^ 0x30);
     t3 = ((port_in(GRA_D) & 0x30) ^ 0x30);
-    outb(GRA_D, t1);
-    outb(GRA_I, t);
+    port_out_r(GRA_D, t1);
+    port_out_r(GRA_I, t);
     return (t2 == t3);
 }
 
@@ -298,12 +298,12 @@ static int ali_test(void)
 
     tmp = port_in(__svgalib_CRT_I);
     ov = GETB(__svgalib_CRT_I, 0x1a);
-    outb(__svgalib_CRT_D, ov & 0xef);
+    port_out_r(__svgalib_CRT_D, ov & 0xef);
     if (cwg()) {
 	ali_lock();
 	return 0;
     }
-    outb(__svgalib_CRT_D, ov | 0x10);
+    port_out_r(__svgalib_CRT_D, ov | 0x10);
     if (!cwg()) {
 	ali_lock();
 	return 0;
@@ -318,7 +318,7 @@ static int ali_test(void)
 
 static void ali_setpage(int page)
 {
-    outw(0x3d6, (last_page = page) | (page << 8));
+    port_outw_r(0x3d6, (last_page = page) | (page << 8));
 }
 
 /* ali_setrdpage( int page )                            Set read page
@@ -329,7 +329,7 @@ static void ali_setpage(int page)
 static void ali_setrdpage(int page)
 {
     last_page = page;
-    outb(0x3d6, page);
+    port_out_r(0x3d6, page);
 }
 
 /* ali_setwrpage( int page )                            Set write page
@@ -340,7 +340,7 @@ static void ali_setrdpage(int page)
 static void ali_setwrpage(int page)
 {
     last_page = page;
-    outb(0x3d7, page);
+    port_out_r(0x3d7, page);
 }
 
 /* ali_setdisplaystart( int address )                   Set display address
@@ -351,9 +351,9 @@ static void ali_setwrpage(int page)
 static void ali_setdisplaystart(int address)
 {
     address >>= 3;
-    outw(__svgalib_CRT_I, 0x0c | (address & 0x00ff00));
-    outw(__svgalib_CRT_I, 0x0d | ((address & 0x00ff) << 8));
-    outw(__svgalib_CRT_I, 0x20 | ((address & 0x070000) >> 8));
+    port_outw_r(__svgalib_CRT_I, 0x0c | (address & 0x00ff00));
+    port_outw_r(__svgalib_CRT_I, 0x0d | ((address & 0x00ff) << 8));
+    port_outw_r(__svgalib_CRT_I, 0x20 | ((address & 0x070000) >> 8));
 }
 
 /* ali_setlogicalwidth( int width )                     Set scanline length
@@ -364,7 +364,7 @@ static void ali_setdisplaystart(int address)
 
 static void ali_setlogicalwidth(int width)
 {
-    outw(CRT_IC, 0x13 + (width >> 3) * 256);	/* lw3-lw11 */
+    port_outw_r(CRT_IC, 0x13 + (width >> 3) * 256);	/* lw3-lw11 */
 }
 
 /* ali_init ( int force, int par1, int par2)            Initialize chipset
@@ -430,8 +430,8 @@ static int ali_memorydetect(void)
 static void SETB(int port, int idx, int value)
 {
     if (idx != -1)
-	outb(port, idx);
-    outb(port + (idx != -1), value);
+	port_out_r(port, idx);
+    port_out_r(port + (idx != -1), value);
 }
 
 /* GETB (port,index)                            Returns ext. register
@@ -443,7 +443,7 @@ static void SETB(int port, int idx, int value)
 static int GETB(int port, int idx)
 {
     if (idx != -1)
-	outb(port, idx);
+	port_out_r(port, idx);
     return port_in(port + (idx != -1));
 }
 
