@@ -298,14 +298,14 @@ static void et3000_setwrpage(int page)
 
 static void et3000_setdisplaystart(int address)
 {
-    outw(CRT_IC, 0x0d + ((address >> 2) & 0x00ff) * 256);	/* sa2-sa9 */
-    outw(CRT_IC, 0x0c + ((address >> 2) & 0xff00));	/* sa10-sa17 */
+    port_outw_r(CRT_IC, 0x0d + ((address >> 2) & 0x00ff) * 256);	/* sa2-sa9 */
+    port_outw_r(CRT_IC, 0x0c + ((address >> 2) & 0xff00));	/* sa10-sa17 */
     port_in(0x3da);			/* set ATC to addressing mode */
-    outb(ATT_IW, 0x13 + 0x20);	/* select ATC reg 0x13 */
-    outb(ATT_IW, (port_in(ATT_R) & 0xf0) | ((address & 3) << 1));
+    port_out_r(ATT_IW, 0x13 + 0x20);	/* select ATC reg 0x13 */
+    port_out_r(ATT_IW, (port_in(ATT_R) & 0xf0) | ((address & 3) << 1));
     /* write sa0-1 to bits 1-2 */
-    outb(CRT_IC, 0x23);
-    outb(CRT_DC, (port_in(CRT_DC) & 0xfd)
+    port_out_r(CRT_IC, 0x23);
+    port_out_r(CRT_DC, (port_in(CRT_DC) & 0xfd)
 	 | ((address & 0x40000) >> 17));	/* write sa18 to bit 1 */
 }
 
@@ -314,7 +314,7 @@ static void et3000_setdisplaystart(int address)
 
 static void et3000_setlogicalwidth(int width)
 {
-    outw(CRT_IC, 0x13 + (width >> 3) * 256);	/* lw3-lw11 */
+    port_outw_r(CRT_IC, 0x13 + (width >> 3) * 256);	/* lw3-lw11 */
 }
 
 
