@@ -39,7 +39,7 @@ FILE *fdm;
 
 #define SEG_SELECT 0x3CD
 
-static unsigned long base1;
+static int base1;
 /* The following are set by init so that they may be restored to their  */
 /* state in setmode.                                                    */
 static unsigned char pci40std,pci42std,pci57std,pci58std,pci59std=0;
@@ -47,14 +47,12 @@ static unsigned char pci40std,pci42std,pci57std,pci58std,pci59std=0;
 #define LMODEMIN 9    /* No mode below this has been tested for linear    */
 #define LMODEMAX 146  /* No mode above this tested.  These should change. */
 
-static long et6000_mapped_mem = 0;
-
 static CardSpecs *cardspecs;
 static int et6ksav = VGA_MISCOUTPUT + 1;
 static int ET6000_TOTAL_REGS = VGA_MISCOUTPUT + 14;
 static char mem_type;
 static int et6000_memory;
-static int et6000_linear_base;
+static unsigned int et6000_linear_base;
 static int et6000_interlaced(int mode); 
 static unsigned comp_lmn(unsigned clock,float fac);
 static int et6000_chiptype = 0; 
@@ -63,7 +61,7 @@ static int x3_4,x3_5,x3_8 = 0,x3_a; /* On init these get set according */
 union longword {
   unsigned char b[4];
   unsigned short w[2];
-  unsigned long l;
+  unsigned int l;
 };
 
 static unsigned int cursor_colors[16*2];
@@ -444,7 +442,7 @@ static int et6000_map_horizontal_crtc(int bpp, int pixelclock, int htiming)
 static int  et6000_init(int force, int par1, int par2)
 {
   unsigned char mem_cfg_reg;
-  unsigned long buf[64];  /* 256 bytes of the pci bus registers. */
+  unsigned int buf[64];  /* 256 bytes of the pci bus registers. */
 
 #ifdef DB6K
 #include <sys/stat.h>
@@ -479,8 +477,8 @@ static int  et6000_init(int force, int par1, int par2)
       x3_8 = 0x3b8;
 
     et6000_linear_base = 0;
-		if(__svgalib_pci_find_vendor_vga(0x100c,buf,0) == 0 &&
-		   (buf[0] == 0x3208100c))
+		if(__svgalib_pci_find_vendor_vga_pos(0x100c,buf) &&
+		   (buf[0] == 0x3208100cu))
 		  {
 DPRT("Found et6000\n");
 		et6000_chiptype = ET6000;   /* Defined in vga.h */
@@ -488,8 +486,8 @@ DPRT("Found et6000\n");
 		else 
 		  {
 #ifdef DB6K 
-		   fprintf(outf,"Can't find et6000 chipset. buf[0] = 0x%8lx\n",
-			(unsigned long) buf[0]);
+		   fprintf(outf,"Can't find et6000 chipset. buf[0] = 0x%08x\n",
+			buf[0]);
 #endif
 		    return(0);
 		  }
@@ -521,8 +519,8 @@ DPRT("Found et6000\n");
 		{
 		  int i;
 		  for(i = 0;i < 64;i+=4)
-			fprintf(outf,"%08x     %08lx  %08lx  %08lx  %08lx\n",
-				(i/4) << 4,buf[i+3],buf[i+2],buf[i+1],buf[i]);
+			fprintf(outf,"%08x     %08x  %08x  %08x  %08x\n",
+				(unsigned int)(i*4),buf[i+3],buf[i+2],buf[i+1],buf[i]);
 		  fprintf(outf,"\npci40std 0x%02x  pci42std 0x%02x  pci58std "
                   "0x%02x  pci59std 0x%02x\n"
 		  "mem_cfg_reg 0x%02x mem_type 0x%02x\n",pci40std,
@@ -897,7 +895,6 @@ static int  et6000_linear(int op, int param)
 #ifdef DB6K
       fprintf(outf,"ENABLE, param = 0x%x\n",param);
 #endif
-      et6000_mapped_mem = param;
       port_out(0,SEG_SELECT);
       port_out(0,0x3cb);
       port_out(5,GRA_I);
