@@ -1,27 +1,31 @@
 #include <sys/types.h>
 #include <sys/ioctl.h>
 #include <sys/mman.h>
-#include <linux/fb.h>
 #include <sys/kd.h>
 #include <unistd.h>
 #include <fcntl.h>
 #include <stdio.h>
 #include <stdlib.h>
 
+#include "fb_lnx.h"
 #include "vga.h"
 #include "libvga.h"
 #include "driver.h"
 #include "timing.h"
 #include "interface.h"
 
-static int fbdev_fd;
-static int fbdev_vgamode;
+/* #define DEBUG */
+
+static int fbdev_fd = -1;
+static int fbdev_vgamode = 0;
+static int fbdev_banked_pointer_emulated = 1;
 static size_t fbdev_memory;
 static size_t fbdev_startaddressrange;
 static CardSpecs *cardspecs;
 static struct console_font_op fbdev_font;
 /* Card Specs */
 static int fbdev_setpalette(int index, int red, int green, int blue);
+static void fbdev_set_virtual_height(struct fb_var_screeninfo *info);
 static int dacmode;
 
 static int fbdev_match_programmable_clock(int clock)
@@ -66,8 +70,6 @@ static int fbdev_init(int force, int par1, int par2)
 	struct fb_fix_screeninfo info;
 	int fd;
 
-//        __svgalib_novga=1;
-
 	if ((fd = open("/dev/fb0", O_RDWR)) < 0)
 	{
 		return -1;
@@ -79,6 +81,12 @@ static int fbdev_init(int force, int par1, int par2)
 		return -1;
 	}
 
+	/*  Ensure this file is closed if we ever exec something else...  */
+	if (fcntl(fd, F_SETFD, 1) == -1) {
+		perror("fcntl 007");
+		exit(-1);
+	}
+
 	fbdev_memory = info.smem_len;
 	fbdev_fd = fd;
 
@@ -89,7 +97,7 @@ static int fbdev_init(int force, int par1, int par2)
 	}
 	fbdev_startaddressrange -= 1;
     
-	__svgalib_modeinfo_linearset |= IS_LINEAR;
+	__svgalib_modeinfo_linearset |= LINEAR_CAN;
 	
 	cardspecs = malloc(sizeof(CardSpecs));
 	cardspecs->videoMemory = fbdev_memory/1024;
@@ -112,14 +120,16 @@ static int fbdev_init(int force, int par1, int par2)
 	cardspecs->mapHorizontalCrtc = fbdev_map_horizontal_crtc;
 
 	__svgalib_driverspecs = &__svgalib_fbdev_driverspecs;
-	__svgalib_banked_mem_base = (unsigned int)info.smem_start;
+	__svgalib_banked_mem_base = (unsigned long)info.smem_start;
 	__svgalib_banked_mem_size = 0x10000;
-	__svgalib_linear_mem_base = (unsigned int)info.smem_start;
+	__svgalib_linear_mem_base = 0;
+	__svgalib_linear_mem_phys_addr = (unsigned long)info.smem_start;
 	__svgalib_linear_mem_size = fbdev_memory;
+	__svgalib_linear_mem_fd = fbdev_fd;
 
         dacmode = 6;
         
-        fprintf(stderr,"Using fbdev, %iKB at %08x\n",fbdev_memory/1024, (unsigned int)info.smem_start);
+        fprintf(stderr,"Using fbdev, %iKB at %08x\n",(int)fbdev_memory/1024, (unsigned int)info.smem_start);
 
 	return 0;
 }
@@ -131,25 +141,18 @@ static int fbdev_test(void)
 
 static void fbdev_setpage(int page)
 {
-	static int oldpage = 0;
-
-	if (page != oldpage)
+	if (fbdev_vgamode)
 	{
-//		munmap(BANKED_POINTER, __svgalib_banked_mem_size);
-		if (page)
-			mmap(BANKED_POINTER,
+		__svgalib_vga_driverspecs.__svgalib_setpage(page);
+	}
+	else
+	{
+		mmap(BANKED_POINTER,
 			     __svgalib_banked_mem_size,
 			     PROT_READ | PROT_WRITE,
 			     MAP_SHARED | MAP_FIXED,
 			     fbdev_fd, page << 16);
-		else
-			mmap(BANKED_POINTER,
-			     __svgalib_banked_mem_size,
-			     PROT_READ | PROT_WRITE,
-			     MAP_SHARED | MAP_FIXED,
-			     __svgalib_mem_fd,
-			     __svgalib_banked_mem_base);
-		oldpage = page;
+		fbdev_banked_pointer_emulated = 1;
 	}
 }
 
@@ -158,11 +161,6 @@ static int fbdev_screeninfo(struct fb_var_screeninfo *info, int mode)
 	ModeTiming modetiming;
 	ModeInfo *modeinfo;
 
-	/* The VGA modes don't work */
-
-	if (IS_IN_STANDARD_VGA_DRIVER(mode))
-		return 1;
-
 	if (ioctl(fbdev_fd, FBIOGET_VSCREENINFO, info))
 		return 1;
 
@@ -223,6 +221,8 @@ static int fbdev_screeninfo(struct fb_var_screeninfo *info, int mode)
 	if (modetiming.flags & PVSYNC)
 		info->sync |= FB_SYNC_VERT_HIGH_ACT;
 
+	fbdev_set_virtual_height(info);
+
 	return 0;
 }
 
@@ -235,26 +235,103 @@ static void fbdev_set_virtual_height(struct fb_var_screeninfo *info)
 		maxpixels /= bytesperpixel;
 
 	info->yres_virtual = maxpixels / info->xres_virtual;
+	if (info->yres_virtual > 8192)
+	        info->yres_virtual = 8192;
 }
 
+static int fbdev_put_vscreeninfo(struct fb_var_screeninfo *info)
+{
+	if (!ioctl(fbdev_fd, FBIOPUT_VSCREENINFO, info))
+		return 0;
+
+	/* try again with an yres virtual of 2x yres */
+	info->yres_virtual = 2 * info->yres;
+	if (!ioctl(fbdev_fd, FBIOPUT_VSCREENINFO, info))
+		return 0;
+
+	/* last try, with an yres_virtual of yres */
+	info->yres_virtual = info->yres;
+	if (!ioctl(fbdev_fd, FBIOPUT_VSCREENINFO, info))
+		return 0;
+
+	/* we failed */
+	return 1;
+}
+
+#ifdef DEBUG
+static void print_vinfo(struct fb_var_screeninfo *vinfo)
+{
+        fprintf(stderr, "\txres: %d\n", vinfo->xres);
+        fprintf(stderr, "\tyres: %d\n", vinfo->yres);
+        fprintf(stderr, "\txres_virtual: %d\n", vinfo->xres_virtual);
+        fprintf(stderr, "\tyres_virtual: %d\n", vinfo->yres_virtual);
+        fprintf(stderr, "\txoffset: %d\n", vinfo->xoffset);
+        fprintf(stderr, "\tyoffset: %d\n", vinfo->yoffset);
+        fprintf(stderr, "\tbits_per_pixel: %d\n", vinfo->bits_per_pixel);
+        fprintf(stderr, "\tgrayscale: %d\n", vinfo->grayscale);
+        fprintf(stderr, "\tnonstd: %d\n", vinfo->nonstd);
+        fprintf(stderr, "\tactivate: %d\n", vinfo->activate);
+        fprintf(stderr, "\theight: %d\n", vinfo->height);
+        fprintf(stderr, "\twidth: %d\n", vinfo->width);
+        fprintf(stderr, "\taccel_flags: %d\n", vinfo->accel_flags);
+        fprintf(stderr, "\tpixclock: %d\n", vinfo->pixclock);
+        fprintf(stderr, "\tleft_margin: %d\n", vinfo->left_margin);  
+        fprintf(stderr, "\tright_margin: %d\n", vinfo->right_margin);
+        fprintf(stderr, "\tupper_margin: %d\n", vinfo->upper_margin);
+        fprintf(stderr, "\tlower_margin: %d\n", vinfo->lower_margin);
+        fprintf(stderr, "\thsync_len: %d\n", vinfo->hsync_len);
+        fprintf(stderr, "\tvsync_len: %d\n", vinfo->vsync_len);
+        fprintf(stderr, "\tsync: %d\n", vinfo->sync);
+        fprintf(stderr, "\tvmode: %d\n", vinfo->vmode);
+        fprintf(stderr, "\tred: %d/%d\n", vinfo->red.length, vinfo->red.offset);
+        fprintf(stderr, "\tgreen: %d/%d\n", vinfo->green.length, vinfo->green.offset);
+        fprintf(stderr, "\tblue: %d/%d\n", vinfo->blue.length, vinfo->blue.offset);
+        fprintf(stderr, "\talpha: %d/%d\n", vinfo->transp.length, vinfo->transp.offset);
+	fflush(stderr);
+}
+#endif
+
 static int fbdev_setmode(int mode, int prv_mode)
 {
 	struct fb_var_screeninfo info;
 
 	if (IS_IN_STANDARD_VGA_DRIVER(mode))
 	{
+		if (__svgalib_fbdev_novga)
+			return 1;
 		if (__svgalib_vga_driverspecs.setmode(mode, prv_mode))
 			return 1;
+		if (fbdev_banked_pointer_emulated)
+		{
+			__svgalib_banked_mem_base = 0xA0000;
+			map_banked(MAP_FIXED);
+			fbdev_banked_pointer_emulated=0;
+		}
 		fbdev_vgamode = 1;
 		return 0;
 	}
+	
+	if (!fbdev_banked_pointer_emulated)
+	{
+		__svgalib_banked_mem_base = __svgalib_linear_mem_phys_addr;
+		map_banked(MAP_FIXED);
+		fbdev_banked_pointer_emulated=1;
+	}
+
 	if (fbdev_screeninfo(&info, mode))
 		return 1;
 
-	fbdev_set_virtual_height(&info);
-
-	if (ioctl(fbdev_fd, FBIOPUT_VSCREENINFO, &info))
+	info.activate = FB_ACTIVATE_NOW;
+#ifdef DEBUG
+        fprintf(stderr, "Vinfo: before putvinfo\n");
+	print_vinfo(&info);
+#endif
+	if (fbdev_put_vscreeninfo(&info))
 		return 1;
+#ifdef DEBUG
+        fprintf(stderr, "Vinfo: after putvinfo\n");
+	print_vinfo(&info);
+#endif
 
 	fbdev_vgamode = 0;
         if(info.bits_per_pixel>16) {
@@ -278,7 +355,12 @@ static int fbdev_modeavailable(int mode)
 	unsigned g, bpp;
 
 	if (IS_IN_STANDARD_VGA_DRIVER(mode))
+	{
+		if (__svgalib_fbdev_novga)
+			return 0;
+		else
 		return __svgalib_vga_driverspecs.modeavailable(mode);
+	}
 
 	if (fbdev_screeninfo(&info, mode))
 		return 0;
@@ -287,7 +369,7 @@ static int fbdev_modeavailable(int mode)
         bpp = info.bits_per_pixel;
 
 	info.activate = FB_ACTIVATE_TEST;
-	if (ioctl(fbdev_fd, FBIOPUT_VSCREENINFO, &info))
+	if (fbdev_put_vscreeninfo(&info))
 		return 0;
 
         if (info.bits_per_pixel != bpp )
@@ -336,8 +418,7 @@ static void fbdev_setlogicalwidth(int width)
 
 	info.xres_virtual = width;
 	fbdev_set_virtual_height(&info);
-
-	ioctl(fbdev_fd, FBIOPUT_VSCREENINFO, &info);
+	fbdev_put_vscreeninfo(&info);
 }
 
 static void fbdev_getmodeinfo(int mode, vga_modeinfo * modeinfo)
@@ -345,6 +426,9 @@ static void fbdev_getmodeinfo(int mode, vga_modeinfo * modeinfo)
 	struct fb_var_screeninfo info;
 	int maxpixels = fbdev_memory;
 
+	if (IS_IN_STANDARD_VGA_DRIVER(mode))
+		return __svgalib_vga_driverspecs.getmodeinfo(mode, modeinfo);
+
 	if (modeinfo->bytesperpixel)
 		maxpixels /= modeinfo->bytesperpixel;
 
@@ -358,10 +442,11 @@ static void fbdev_getmodeinfo(int mode, vga_modeinfo * modeinfo)
 		return;
 
 	info.activate = FB_ACTIVATE_TEST;
-	if (ioctl(fbdev_fd, FBIOPUT_VSCREENINFO, &info))
+	if (fbdev_put_vscreeninfo(&info))
 		return;
 
 	modeinfo->linewidth = info.xres_virtual * info.bits_per_pixel / 8;
+	modeinfo->maxpixels = info.xres_virtual * info.yres_virtual;
 }
 
 static int fbdev_linear(int op, int param)
@@ -369,7 +454,7 @@ static int fbdev_linear(int op, int param)
 	switch(op)
 	{
 	case LINEAR_QUERY_BASE:
-		return __svgalib_linear_mem_base;
+		return __svgalib_linear_mem_phys_addr;
 	case LINEAR_ENABLE:
 	case LINEAR_DISABLE:
 		return 0;
