@@ -61,7 +61,7 @@ static void i740_unlock(void);
 static void i740_lock(void);
 
 static int i740_memory, I740HasSGRAM;
-static int i740_is_linear, i740_linear_base, i740_mmio_base;
+static unsigned int i740_linear_base, i740_mmio_base;
 
 static CardSpecs *cardspecs;
 
@@ -97,13 +97,7 @@ static void i740_setpage(int page)
    i740_outxr(14,page);
 }
 
-static int __svgalib_i740_inlinearmode(void)
-{
-return i740_is_linear;
-}
-
 /* Fill in chipset specific mode information */
-
 static void i740_getmodeinfo(int mode, vga_modeinfo *modeinfo)
 {
 
@@ -116,9 +110,7 @@ static void i740_getmodeinfo(int mode, vga_modeinfo *modeinfo)
     modeinfo->flags &= ~HAVE_RWPAGE;
 
     if (modeinfo->bytesperpixel >= 1) {
-	if(i740_linear_base)modeinfo->flags |= CAPABLE_LINEAR;
-        if (__svgalib_i740_inlinearmode())
-	    modeinfo->flags |= IS_LINEAR | LINEAR_MODE;
+		if(i740_linear_base)modeinfo->flags |= CAPABLE_LINEAR;
     }
 }
 
@@ -612,11 +604,11 @@ static void i740_lock(void)
 static int i740_test(void)
 {
     int found;
-    long buf[64];
+    unsigned int buf[64];
     
-    found=__svgalib_pci_find_vendor_vga(VENDOR_ID,buf,0);
+    found=__svgalib_pci_find_vendor_vga_pos(VENDOR_ID,buf);
     
-    if(!found&&
+    if(found&&
        ((((buf[0]>>16)&0xffff)==I740_ID_PCI)||
         (((buf[0]>>16)&0xffff)==I740_ID_AGP))){
           i740_init(0,0,0);
@@ -652,19 +644,19 @@ static void i740_setlogicalwidth(int width)
 
 static int i740_linear(int op, int param)
 {
-    if (op==LINEAR_ENABLE){i740_is_linear=1; return 0;};
-    if (op==LINEAR_DISABLE){i740_is_linear=0; return 0;};
-    if (op==LINEAR_QUERY_BASE) return i740_linear_base;
-    if (op == LINEAR_QUERY_RANGE || op == LINEAR_QUERY_GRANULARITY) return 0;		/* No granularity or range. */
-        else return -1;		/* Unknown function. */
+    if (op==LINEAR_DISABLE || op==LINEAR_ENABLE) return 0;
+    if (op==LINEAR_QUERY_BASE) return __svgalib_linear_mem_base;
+    if (op == LINEAR_QUERY_RANGE || op == LINEAR_QUERY_GRANULARITY)
+        return 0;       /* No granularity or range. */
+    return -1;      /* Unknown function. */
 }
 
 static unsigned char cur_colors[16*6];
 
 static int i740_cursor( int cmd, int p1, int p2, int p3, int p4, void *p5) {
     int i, j, tmp;
-    unsigned long *b3;
-    unsigned long l1, l2, l3, l4;
+    unsigned int *b3;
+    unsigned int l1, l2, l3, l4;
     
     switch(cmd){
         case CURSOR_INIT:
@@ -695,7 +687,7 @@ static int i740_cursor( int cmd, int p1, int p2, int p3, int p4, void *p5) {
         case CURSOR_IMAGE:
             i=i740_memory*1024-(p1+1)*4096;
             if(i>4096*1024)i-=4096*1024;
-            b3=(unsigned long *)p5;
+            b3=(unsigned int *)p5;
             switch(p2) {
                 case 0:
                     cur_colors[p1*6]=(p3&0xff0000)>>16;
@@ -714,10 +706,10 @@ static int i740_cursor( int cmd, int p1, int p2, int p3, int p4, void *p5) {
                         l2=(l2<<24)|(l2>>24)|((l2>>8)&0xff00)|((l2<<8)&0xff0000);
                         l3=(l3<<24)|(l3>>24)|((l3>>8)&0xff00)|((l3<<8)&0xff0000);
                         l4=(l4<<24)|(l4>>24)|((l4>>8)&0xff00)|((l4<<8)&0xff0000);
-                        *(unsigned long *)(LINEAR_POINTER+i+16*j)=l2;
-                        *(unsigned long *)(LINEAR_POINTER+i+16*j+4)=l4;
-                        *(unsigned long *)(LINEAR_POINTER+i+16*j+8)=l1;
-                        *(unsigned long *)(LINEAR_POINTER+i+16*j+12)=l3;
+                        *(unsigned int *)(LINEAR_POINTER+i+16*j)=l2;
+                        *(unsigned int *)(LINEAR_POINTER+i+16*j+4)=l4;
+                        *(unsigned int *)(LINEAR_POINTER+i+16*j+8)=l1;
+                        *(unsigned int *)(LINEAR_POINTER+i+16*j+12)=l3;
                     }
                 break;
             }
@@ -775,7 +767,7 @@ DriverSpecs __svgalib_i740_driverspecs =
 /* Initialize chipset (called after detection) */
 static int i740_init(int force, int par1, int par2)
 {
-    unsigned long buf[64];
+    unsigned int buf[64];
     int found=0;
     int temp;
     
@@ -784,9 +776,9 @@ static int i740_init(int force, int par1, int par2)
 
     i740_unlock();
 
-    found=__svgalib_pci_find_vendor_vga(VENDOR_ID,buf,0);
+    found=__svgalib_pci_find_vendor_vga_pos(VENDOR_ID,buf);
     i740_linear_base=0;
-    if(!found&&((((buf[0]>>16)&0xffff)==I740_ID_PCI)||(((buf[0]>>16)&0xffff)==I740_ID_AGP))){
+    if(found&&((((buf[0]>>16)&0xffff)==I740_ID_PCI)||(((buf[0]>>16)&0xffff)==I740_ID_AGP))){
        i740_linear_base=buf[4]&0xffffff00;
        i740_mmio_base=buf[5]&0xffffff00;
     };
@@ -814,10 +806,10 @@ static int i740_init(int force, int par1, int par2)
     I740HasSGRAM = !((temp & DRAM_RAS_TIMING) || (temp & DRAM_RAS_PRECHARGE));
 
     if (__svgalib_driver_report) {
-	fprintf(stderr,"Using I740 driver, %iKB.\n",i740_memory);
+		fprintf(stderr,"Using I740 driver, %iKB.\n",i740_memory);
     };
     
-	__svgalib_modeinfo_linearset |= IS_LINEAR;
+	__svgalib_modeinfo_linearset |= LINEAR_CAN;
 	
     cardspecs = malloc(sizeof(CardSpecs));
     cardspecs->videoMemory = i740_memory;
