@@ -3,8 +3,6 @@
   written by Matan Ziv-Av.
 */
 
-#define USE_GTT 1
-
 #include <stdlib.h>
 #include <stdio.h>		
 #include <string.h>
@@ -24,6 +22,8 @@
 #include <sys/ioctl.h>
 #include "svgalib_helper.h"
 
+int __svgalib_i810_usegtt=1;
+
 typedef struct {
 /* 00 */
     unsigned char DisplayControl;
@@ -70,7 +70,7 @@ static void unlock(void);
 static void lock(void);
 
 static int memory, lmfreq;
-static int is_linear, linear_base, mmio_base;
+static unsigned int linear_base, mmio_base;
 static unsigned int cur_base;
 static CardSpecs *cardspecs;
 
@@ -79,13 +79,7 @@ static void setpage(int page)
    __svgalib_outgra(0x11,page);
 }
 
-static int __svgalib_inlinearmode(void)
-{
-return is_linear;
-}
-
 /* Fill in chipset specific mode information */
-
 static void getmodeinfo(int mode, vga_modeinfo *modeinfo)
 {
 
@@ -98,11 +92,9 @@ static void getmodeinfo(int mode, vga_modeinfo *modeinfo)
     modeinfo->flags &= ~HAVE_RWPAGE;
 
     if (modeinfo->bytesperpixel >= 1) {
-#ifdef USE_GTT
-	if(linear_base)modeinfo->flags |= CAPABLE_LINEAR;
-        if (__svgalib_inlinearmode())
-	    modeinfo->flags |= IS_LINEAR | LINEAR_MODE;
-#endif
+		if(__svgalib_i810_usegtt) {
+			if(linear_base)modeinfo->flags |= CAPABLE_LINEAR;
+		}
     }
 }
 
@@ -368,26 +360,26 @@ static void initializemode(unsigned char *moderegs,
 	break;
         case 15:
         case 16:
-	    if (modeinfo->greenWeight == 5) {
-	        new->PixelPipeCfg1 = DISPLAY_15BPP_MODE;
-	    } else {
-	        new->PixelPipeCfg1 = DISPLAY_16BPP_MODE;
-	    }
-	    break;
+	    	if (modeinfo->greenWeight == 5) {
+	        	new->PixelPipeCfg1 = DISPLAY_15BPP_MODE;
+		    } else {
+		        new->PixelPipeCfg1 = DISPLAY_16BPP_MODE;
+	    	}
+	    	break;
         case 24:
-	    new->PixelPipeCfg1 = DISPLAY_24BPP_MODE;
-	    break;
+		    new->PixelPipeCfg1 = DISPLAY_24BPP_MODE;
+		    break;
         case 32:
-	    new->PixelPipeCfg1 = DISPLAY_32BPP_MODE;
-	    break;
+	    	new->PixelPipeCfg1 = DISPLAY_32BPP_MODE;
+		    break;
         default:
-	    break;
+		    break;
     }
 
     if (modeinfo->bitsPerPixel>8)
-	new->PixelPipeCfg0 = DAC_8_BIT;
+		new->PixelPipeCfg0 = DAC_8_BIT;
     else
-	new->PixelPipeCfg0 = DAC_6_BIT;
+		new->PixelPipeCfg0 = DAC_6_BIT;
 
     new->PixelPipeCfg2 = 0;
     new->PixelPipeCfg1 |= 0x10;
@@ -396,13 +388,13 @@ static void initializemode(unsigned char *moderegs,
     new->IOControl = EXTENDED_CRTC_CNTL;
 
     /* Turn on linear and page mapping */
-#ifdef USE_GTT
-    new->AddressMapping =  LINEAR_MODE_ENABLE | 8 ;
-    new->DisplayControl =  1;
-#else
-    new->AddressMapping = PACKED_MODE_ENABLE | PAGE_MAPPING_ENABLE ;
-    new->DisplayControl =  2;
-#endif
+	if(__svgalib_i810_usegtt) {
+    	new->AddressMapping =  LINEAR_MODE_ENABLE | 8 ;
+    	new->DisplayControl =  1;
+	} else {
+    	new->AddressMapping = PACKED_MODE_ENABLE | PAGE_MAPPING_ENABLE ;
+    	new->DisplayControl =  2;
+	}
     
     /* Calculate the extended CRTC regs */
     new->ExtVertTotal = (modetiming->CrtcVTotal - 2) >> 8;
@@ -414,9 +406,9 @@ static void initializemode(unsigned char *moderegs,
 
     /* Turn on interlaced mode if necessary */
     if (modetiming->flags & INTERLACED)
-	new->InterlaceControl = INTERLACE_ENABLE;
+		new->InterlaceControl = INTERLACE_ENABLE;
     else
-	new->InterlaceControl = INTERLACE_DISABLE;
+		new->InterlaceControl = INTERLACE_DISABLE;
 
     moderegs[VGA_AR11] = 0;
 
@@ -433,7 +425,8 @@ static void initializemode(unsigned char *moderegs,
     new->ExtStartAddrHi=0;
 
     /* Calculate the FIFO Watermark and Burst Length. */
-    new->LMI_FIFO_Watermark = I810CalcWatermark(modetiming->pixelClock/1000,modeinfo->bitsPerPixel, lmfreq, 0);
+    new->LMI_FIFO_Watermark = I810CalcWatermark(modetiming->pixelClock/1000,
+			modeinfo->bitsPerPixel, lmfreq, 0);
 
     new->CursorControl= CURSOR_ORIGIN_DISPLAY | CURSOR_MODE_32_4C_AX;
 
@@ -449,18 +442,19 @@ static int setmode(int mode, int prv_mode)
     ModeInfo *modeinfo;
 
     if (IS_IN_STANDARD_VGA_DRIVER(mode)) {
-	return __svgalib_vga_driverspecs.setmode(mode, prv_mode);
+		return __svgalib_vga_driverspecs.setmode(mode, prv_mode);
     }
-    if (!modeavailable(mode))
-	return 1;
+
+	if (!modeavailable(mode)) return 1;
 
     modeinfo = __svgalib_createModeInfoStructureForSvgalibMode(mode);
 
     modetiming = malloc(sizeof(ModeTiming));
-    if (__svgalib_getmodetiming(modetiming, modeinfo, cardspecs)) {
-	free(modetiming);
-	free(modeinfo);
-	return 1;
+    
+	if (__svgalib_getmodetiming(modetiming, modeinfo, cardspecs)) {
+		free(modetiming);
+		free(modeinfo);
+		return 1;
     }
 
     moderegs = malloc(I810_TOTAL_REGS);
@@ -502,13 +496,13 @@ static void lock(void)
 static int test(void)
 {
     int found;
-    long buf[64];
+    unsigned int buf[64];
     int id;
     
-    found=__svgalib_pci_find_vendor_vga(VENDOR_ID,buf,0);
+    found=__svgalib_pci_find_vendor_vga_pos(VENDOR_ID,buf);
     id=buf[0]>>16;
     
-    if( !found && ((id==ID10) || (id==ID10DC) || (id==ID10E) || (id==ID15)) ){
+    if(found && ((id==ID10) || (id==ID10DC) || (id==ID10E) || (id==ID15)) ){
           init(0,0,0);
           return 1;
     };
@@ -532,11 +526,9 @@ static void setdisplaystart(int address)
 
 static void setlogicalwidth(int width)
 {   
-#ifdef USE_GTT
     int offset = width >> 3;
-#else
-    int offset = width >> 4;
-#endif
+	
+	if(!__svgalib_i810_usegtt) offset>>=1;
  
     __svgalib_outcrtc(0x13,offset&0xff);
     __svgalib_outcrtc(EXT_OFFSET, offset>>8);
@@ -545,8 +537,7 @@ static void setlogicalwidth(int width)
 
 static int linear(int op, int param)
 {
-    if (op==LINEAR_ENABLE){is_linear=1; return 0;};
-    if (op==LINEAR_DISABLE){is_linear=0; return 0;};
+    if (op==LINEAR_ENABLE || op==LINEAR_DISABLE) return 0;
     if (op==LINEAR_QUERY_BASE) return linear_base;
     if (op == LINEAR_QUERY_RANGE || op == LINEAR_QUERY_GRANULARITY) return 0;		/* No granularity or range. */
         else return -1;		/* Unknown function. */
@@ -556,8 +547,8 @@ static unsigned char cur_colors[16*6];
 
 static int cursor( int cmd, int p1, int p2, int p3, int p4, void *p5) {
     int i, j, tmp;
-    unsigned long *b3;
-    unsigned long l1, l2, l3, l4;
+    unsigned int *b3;
+    unsigned int l1, l2, l3, l4;
 
     switch(cmd){
         case CURSOR_INIT:
@@ -586,7 +577,7 @@ static int cursor( int cmd, int p1, int p2, int p3, int p4, void *p5) {
             break;
         case CURSOR_IMAGE:
             i=memory*1024-(p1+1)*256;
-            b3=(unsigned long *)p5;
+            b3=(unsigned int *)p5;
             switch(p2) {
                 case 0:
                     cur_colors[p1*6]=(p3&0xff0000)>>16;
@@ -605,10 +596,10 @@ static int cursor( int cmd, int p1, int p2, int p3, int p4, void *p5) {
                         l2=(l2<<24)|(l2>>24)|((l2>>8)&0xff00)|((l2<<8)&0xff0000);
                         l3=(l3<<24)|(l3>>24)|((l3>>8)&0xff00)|((l3<<8)&0xff0000);
                         l4=(l4<<24)|(l4>>24)|((l4>>8)&0xff00)|((l4<<8)&0xff0000);
-                        *(unsigned long *)(LINEAR_POINTER+i+16*j)=l2;
-                        *(unsigned long *)(LINEAR_POINTER+i+16*j+4)=l4;
-                        *(unsigned long *)(LINEAR_POINTER+i+16*j+8)=l1;
-                        *(unsigned long *)(LINEAR_POINTER+i+16*j+12)=l3;
+                        *(unsigned int *)(LINEAR_POINTER+i+16*j)=l2;
+                        *(unsigned int *)(LINEAR_POINTER+i+16*j+4)=l4;
+                        *(unsigned int *)(LINEAR_POINTER+i+16*j+8)=l1;
+                        *(unsigned int *)(LINEAR_POINTER+i+16*j+12)=l3;
                     }
                 break;
             }
@@ -642,11 +633,7 @@ DriverSpecs __svgalib_i810_driverspecs =
     lock,
     test,
     init,
-#ifdef USE_GTT
-    __svgalib_emul_setpage,
-#else
     setpage,
-#endif
     NULL,
     NULL,
     setmode,
@@ -670,19 +657,26 @@ DriverSpecs __svgalib_i810_driverspecs =
 /* Initialize chipset (called after detection) */
 static int init(int force, int par1, int par2)
 {
-    unsigned long buf[64];
+    unsigned int buf[64];
     unsigned int t, i, id;
     int found=0;
     
-    found=__svgalib_pci_find_vendor_vga(VENDOR_ID,buf,0);
+    found=__svgalib_pci_find_vendor_vga_pos(VENDOR_ID,buf);
     linear_base=0;
     id=buf[0]>>16;
     
-    if( !found && ((id==ID10) || (id==ID10DC) || (id==ID10E) || (id==ID15)) ){
-       linear_base=buf[4]&0xffffff00;
-       mmio_base=buf[5]&0xffffff00;
-    } else return -1; 
-    ;
+    if( found && ((id==ID10) || (id==ID10DC) || (id==ID10E) || (id==ID15)) ){
+       	linear_base=buf[4]&0xffffff00;
+		mmio_base=buf[5]&0xffffff00;
+    } else return 1; 
+
+	if(__svgalib_nohelper && __svgalib_i810_usegtt) {
+		/* Can't use GTT withoout helper */
+
+		fprintf(stderr, "I810: WARNING: Can't use GTT without kernel helper.\n"
+				        "               Using I810 driver in no-gtt mode.\n");
+		__svgalib_i810_usegtt=0;
+	}
 
     __svgalib_mmio_base=mmio_base;
     __svgalib_mmio_size=512*0x400;
@@ -696,29 +690,35 @@ static int init(int force, int par1, int par2)
         memory = 512;
     };
 
-#ifdef USE_GTT
-    if(v_readl(0x2020) & 1) {
-       /* GTT already set */
-       memory = 4096;
-    } else {
-        memory = 4096;
-        ioctl(__svgalib_mem_fd, SVGAHELPER_I810GTT, &t);
-        v_writel(t|1, 0x2020);
-        for(i=0;i<1024;i++) {
-            t=i;
-            ioctl(__svgalib_mem_fd, SVGAHELPER_I810GTTE, &t);
-            v_writel(t, 0x10000 + 4*i);
-        }
-    }
-    cur_base = (memory>>2)-1;
-    ioctl(__svgalib_mem_fd, SVGAHELPER_I810GTTE, &cur_base);
-    cur_base &= ~1 ;
-    __svgalib_banked_mem_base=linear_base;
-    __svgalib_modeinfo_linearset |= IS_LINEAR;
-#else
-    linear_base=0;
-    __svgalib_banked_mem_base=0xa0000;
-#endif
+	if(__svgalib_i810_usegtt) {
+		if(v_readl(0x2020) & 1) {
+		   /* GTT already set */
+		   memory = 4096;
+		} else {
+			memory = 4096;
+			ioctl(__svgalib_mem_fd, SVGAHELPER_I810GTT, &t);
+			v_writel(t|1, 0x2020);
+			for(i=0;i<1024;i++) {
+				t=i;
+				ioctl(__svgalib_mem_fd, SVGAHELPER_I810GTTE, &t);
+				v_writel(t, 0x10000 + 4*i);
+			}
+		}
+		cur_base = (memory>>2)-1;
+		ioctl(__svgalib_mem_fd, SVGAHELPER_I810GTTE, &cur_base);
+		cur_base &= ~1 ;
+	    __svgalib_banked_mem_base=linear_base;
+		__svgalib_linear_mem_base=linear_base;
+		__svgalib_linear_mem_size=memory*0x400;
+    	__svgalib_modeinfo_linearset |= LINEAR_CAN;
+		__svgalib_emulatepage = 2;
+		__svgalib_i810_driverspecs.__svgalib_setpage = NULL;	
+	} else {
+    	linear_base=0;
+    	__svgalib_banked_mem_base=0xa0000;
+    	__svgalib_banked_mem_size=0x10000;
+		__svgalib_linear_mem_size=0;
+	}
 
     if(buf[20]&0x10) {
         lmfreq=133;
@@ -727,7 +727,7 @@ static int init(int force, int par1, int par2)
     }
 
     if (__svgalib_driver_report) {
-	fprintf(stderr,"Using i810 driver, %iKB.\n",memory);
+		fprintf(stderr,"Using i810 driver, %iKB.\n",memory);
     };
 
     cardspecs = malloc(sizeof(CardSpecs));
@@ -745,8 +745,5 @@ static int init(int force, int par1, int par2)
     cardspecs->mapHorizontalCrtc = map_horizontal_crtc;
     cardspecs->matchProgrammableClock=match_programmable_clock;
     __svgalib_driverspecs = &__svgalib_i810_driverspecs;
-    __svgalib_banked_mem_size=0x10000;
-    __svgalib_linear_mem_base=linear_base;
-    __svgalib_linear_mem_size=memory*0x400;
     return 0;
 }
