@@ -19,8 +19,8 @@ static int mil_init(int, int, int);
 static void mil_unlock(void);
 static void mil_lock(void);
 
-static int mil_memory=0, mil_pciposition;
-static int mil_is_linear, mil_linear_base, mil_mmio_base, mil_chiptype;
+static int mil_memory=0, mil_pciposition, mil_chiptype;
+static unsigned int mil_linear_base, mil_mmio_base;
 static int interleave, rounding;
 
 static CardSpecs *cardspecs;
@@ -40,13 +40,7 @@ static void mil_setpage(int page)
 	mil_outext(4, page);
 }
 
-static int __svgalib_mil_inlinearmode(void)
-{
-return mil_is_linear;
-}
-
 /* Fill in chipset specific mode information */
-
 static void mil_getmodeinfo(int mode, vga_modeinfo *modeinfo)
 {
 
@@ -64,9 +58,7 @@ static void mil_getmodeinfo(int mode, vga_modeinfo *modeinfo)
     modeinfo->flags &= ~HAVE_RWPAGE;
 
     if (modeinfo->bytesperpixel >= 1) {
-	if(mil_linear_base)modeinfo->flags |= CAPABLE_LINEAR;
-        if (__svgalib_mil_inlinearmode())
-	    modeinfo->flags |= IS_LINEAR | LINEAR_MODE;
+		if(mil_linear_base)modeinfo->flags |= CAPABLE_LINEAR;
     }
 }
 
@@ -109,7 +101,7 @@ const static unsigned char MGADACbpp32[DACREGSIZE] = {
 
 static double
 MGATi3026CalcClock (
-   long f_out, long f_max,
+   int f_out, int f_max,
    int *m, int *n, int *p
 ){
 	int best_m = 0, best_n = 0;
@@ -174,7 +166,7 @@ MGATi3026CalcClock (
 }
 
 static void 
-MGATi3026SetPCLK( MGARegPtr pReg, long f_out, int bpp )
+MGATi3026SetPCLK( MGARegPtr pReg, int f_out, int bpp )
 {
 	/* Pixel clock values */
 	int m, n, p;
@@ -186,7 +178,7 @@ MGATi3026SetPCLK( MGARegPtr pReg, long f_out, int bpp )
 	/* The actual frequency output by the clock */
 	double f_pll;
 
-	long f_max = TI_MAX_VCO_FREQ;
+	int f_max = TI_MAX_VCO_FREQ;
 
 	/* Do the calculations for m, n, and p */
 	f_pll = MGATi3026CalcClock( f_out, f_max, & m, & n, & p );
@@ -730,13 +722,13 @@ static void mil_lock(void)
 
 static int mil_test(void)
 {
-    unsigned long buf[64];
+    unsigned int buf[64];
     int found;
     int id;
     
-    found=__svgalib_pci_find_vendor_vga(VENDOR_ID,buf,0);
+    found=__svgalib_pci_find_vendor_vga_pos(VENDOR_ID,buf);
     id=(buf[0]>>16)&0xffff;
-    if(found)return 0;
+    if(!found)return 0;
     switch(id) {
         case 0x519:
         case 0x51b:
@@ -778,8 +770,8 @@ static void mil_setlogicalwidth(int width)
 
 static int mil_linear(int op, int param)
 {
-    if (op==LINEAR_ENABLE){mil_is_linear=1; return 0;};
-    if (op==LINEAR_DISABLE){mil_is_linear=0; return 0;};
+    if (op==LINEAR_ENABLE){ return 0;};
+    if (op==LINEAR_DISABLE){ return 0;};
     if (op==LINEAR_QUERY_BASE) return mil_linear_base;
     if (op == LINEAR_QUERY_RANGE || op == LINEAR_QUERY_GRANULARITY) return 0;		/* No granularity or range. */
         else return -1;		/* Unknown function. */
@@ -851,7 +843,7 @@ static void __svgalib_mil_outpal(int i, int r, int g, int b)
 
 static int mil_init(int force, int par1, int par2)
 {
-    unsigned long buf[64];
+    unsigned int buf[64];
     int found=0, id;
 
     if (force) {
@@ -860,10 +852,10 @@ static int mil_init(int force, int par1, int par2)
     } else {
     };
 
-    found=__svgalib_pci_find_vendor_vga_pos(VENDOR_ID,buf,0);
+    found=__svgalib_pci_find_vendor_vga_pos(VENDOR_ID,buf);
     mil_linear_base=0;
     id=(buf[0]>>16)&0xffff;
-    if(found != -1) {
+    if(found) {
         mil_pciposition=found;
         switch(id) {
             case 0x519: /* Millennium */
@@ -887,9 +879,11 @@ static int mil_init(int force, int par1, int par2)
     }
 
     if(!mil_memory) {
-        map_linear(mil_linear_base, 8*1024*1024);
-        mil_memory=memorytest(LINEAR_POINTER, 8);
-        unmap_linear(8*1024*1024);
+        __svgalib_linear_mem_base=mil_linear_base;
+        __svgalib_linear_mem_size=8*1024*1024;
+        map_linear(0);
+        mil_memory=memorytest((uint32_t *)LINEAR_POINTER, 8);
+        unmap_linear();
     }
 
     __svgalib_mmio_base=mil_mmio_base;
@@ -917,7 +911,7 @@ static int mil_init(int force, int par1, int par2)
 	fprintf(stderr,"Using Millennium driver, %iKB.\n",mil_memory);
     };
     
-	__svgalib_modeinfo_linearset |= IS_LINEAR;
+	__svgalib_modeinfo_linearset |= LINEAR_CAN;
 	
     cardspecs = malloc(sizeof(CardSpecs));
     cardspecs->videoMemory = mil_memory;
