@@ -10,8 +10,7 @@ Problem: The modes whose width is longer than the width of LCD panel
  --> Please do not select such modes :-)
 
 Note:
-  When use Toshiba Libretto100,110, please define "LIBRETTO100" at
-  line 19 in src/neo.c
+  When use Toshiba Libretto100,110.
   And add the following lines to libvga.config
   -------------------------------------------------------------------
    HorizSync 31.5 70
@@ -38,7 +37,6 @@ Note:
 #include "vgapci.h"
 
 #undef NEO_PCI_BURST
-#undef LIBRETTO100  /* Define if Toshiba Libretto100/110 */
 
 #define TRUE (1)
 #define FALSE (0)
@@ -99,10 +97,11 @@ static int neo_init(int, int, int);
 static void neo_unlock(void);
 static void neo_lock(void);
 
+extern unsigned char __svgalib_neolibretto100;
 static int neo_memory;
 static int NeoChipset;
 static int NeoPanelWidth, NeoPanelHeight;
-static int neo_is_linear, neo_linear_base;
+static unsigned int neo_linear_base;
 static int vgaIOBase;
 
 static CardSpecs *cardspecs;
@@ -137,16 +136,7 @@ static void neo_setwrpage(int page)
   port_outw_r(GRAX, (page << 10) | 0x16); /* set write bank */
 }
 
-static int __svgalib_neo_inlinearmode(void)
-{
-#ifdef DEBUG
-  fprintf(stderr, "neo_inlinearmode\n");
-#endif
-return neo_is_linear;
-}
-
 /* Fill in chipset specific mode information */
-
 static void neo_getmodeinfo(int mode, vga_modeinfo *modeinfo)
 {
 #ifdef DEBUG
@@ -166,9 +156,7 @@ static void neo_getmodeinfo(int mode, vga_modeinfo *modeinfo)
 
 #if 1
     if (modeinfo->bytesperpixel >= 1) {
-	if(neo_linear_base)modeinfo->flags |= CAPABLE_LINEAR;
-        if (__svgalib_neo_inlinearmode())
-	    modeinfo->flags |= IS_LINEAR | LINEAR_MODE;
+		if(neo_linear_base)modeinfo->flags |= CAPABLE_LINEAR;
     }
 #endif
 }
@@ -403,7 +391,7 @@ static void neo_setregs(const unsigned char regs[], int mode)
 #define MAX_D 31
 #define MAX_F 1
 
-static void NeoCalcVCLK(long freq, unsigned char *moderegs)
+static void NeoCalcVCLK(int freq, unsigned char *moderegs)
 {
     int n, d, f;
     double f_out;
@@ -727,20 +715,21 @@ static void neo_lock(void)
 
 static int neo_test(void)
 {
-    unsigned long buf[64];
+    unsigned int buf[64];
     int found=0;
     
-    found=__svgalib_pci_find_vendor_vga(VENDOR_ID,buf,0);
+    found=__svgalib_pci_find_vendor_vga_pos(VENDOR_ID,buf);
     
-    if (found == 0){ /* found */
-      switch ((buf[0] >> 16) & 0xffff){
-      case PCI_CHIP_NM2070: case PCI_CHIP_NM2090: case PCI_CHIP_NM2093:
-      case PCI_CHIP_NM2097: case PCI_CHIP_NM2160: case PCI_CHIP_NM2200:
-       neo_init(0,0,0);
-       return (TRUE);
-      }
-    }
-    return (FALSE);
+    if (found){ /* found */
+  		switch ((buf[0] >> 16) & 0xffff){
+	  		case PCI_CHIP_NM2070: case PCI_CHIP_NM2090: case PCI_CHIP_NM2093:
+	  		case PCI_CHIP_NM2097: case PCI_CHIP_NM2160: case PCI_CHIP_NM2200:
+		 		neo_init(0,0,0);
+		 		return (TRUE);
+  		}
+	}
+
+	return (FALSE);
 }
 
 
@@ -785,8 +774,8 @@ static int neo_linear(int op, int param)
 #ifdef DEBUG
     fprintf(stderr, "neo_linear: %d\n", op);
 #endif
-    if (op==LINEAR_ENABLE){neo_is_linear=1; return 0;};
-    if (op==LINEAR_DISABLE){neo_is_linear=0; return 0;};
+    if (op==LINEAR_ENABLE){ return 0;};
+    if (op==LINEAR_DISABLE){ return 0;};
     if (op==LINEAR_QUERY_BASE) return neo_linear_base;
     if (op == LINEAR_QUERY_RANGE || op == LINEAR_QUERY_GRANULARITY) return 0;		/* No granularity or range. */
         else return -1;		/* Unknown function. */
@@ -847,7 +836,7 @@ DriverSpecs __svgalib_neo_driverspecs =
 
 static int neo_init(int force, int par1, int par2)
 {
-    unsigned long buf[64];
+    unsigned int buf[64];
     int found=0;
     int w;
 
@@ -861,35 +850,34 @@ static int neo_init(int force, int par1, int par2)
       NeoChipset = -1;
     };
 
-    found=__svgalib_pci_find_vendor_vga(VENDOR_ID,buf,0);
+    found=__svgalib_pci_find_vendor_vga_pos(VENDOR_ID,buf);
 
     neo_linear_base=0;
-    if (!found){ /* found */
-      neo_linear_base=buf[4]&0xffffff00;
-      if (NeoChipset < 0)
-	NeoChipset = (buf[0] >> 16) & 0xffff;
-      if (neo_memory < 0){
-	switch (NeoChipset){
-	case PCI_CHIP_NM2070:
-	  neo_memory = 896;
-	  break;
-	case PCI_CHIP_NM2090: case PCI_CHIP_NM2093: case PCI_CHIP_NM2097:
-	  neo_memory = 1152;
-	  break;
-	case PCI_CHIP_NM2160:
-	  neo_memory = 2048;
-	  break;
-	case PCI_CHIP_NM2200:
-	  neo_memory = 2560;
-	  break;
-	default:
-	  neo_memory = 0;
+    if (found){ /* found */
+  		neo_linear_base=buf[4]&0xffffff00;
+  		if (NeoChipset < 0)
+			NeoChipset = (buf[0] >> 16) & 0xffff;
+  		if (neo_memory < 0){
+			switch (NeoChipset){
+				case PCI_CHIP_NM2070:
+			  		neo_memory = 896;
+			  		break;
+				case PCI_CHIP_NM2090: case PCI_CHIP_NM2093: case PCI_CHIP_NM2097:
+			  		neo_memory = 1152;
+			  		break;
+				case PCI_CHIP_NM2160:
+			  		neo_memory = 2048;
+			  		break;
+				case PCI_CHIP_NM2200:
+			  		neo_memory = 2560;
+			  		break;
+				default:
+			  		neo_memory = 0;
+			}
+  		}
 	}
-      }
-    }
-
-    if (__svgalib_driver_report) {
-	fprintf(stderr,"Using NeoMagic driver, %iKB.\n",neo_memory);
+	if (__svgalib_driver_report) {
+		fprintf(stderr,"Using NeoMagic driver, %iKB.\n",neo_memory);
     };
 
     cardspecs = malloc(sizeof(CardSpecs));
@@ -932,11 +920,10 @@ static int neo_init(int force, int par1, int par2)
 	break;
     case 0x01:
 	NeoPanelWidth  = 800;
-#ifdef LIBRETTO100
+	if (__svgalib_neolibretto100)
 	NeoPanelHeight = 480;
-#else /* LIBRETTO100 */
+        else
 	NeoPanelHeight = 600;
-#endif /* LIBRETTO100 */
 	break;
     case 0x02:
 	NeoPanelWidth  = 1024;
@@ -951,7 +938,7 @@ static int neo_init(int force, int par1, int par2)
 	NeoPanelHeight = 480;
     }
     
-	__svgalib_modeinfo_linearset |= IS_LINEAR;
+	__svgalib_modeinfo_linearset |= LINEAR_CAN;
 	
     cardspecs->flags = INTERLACE_DIVIDE_VERT | CLOCK_PROGRAMMABLE;
     cardspecs->maxHorizontalCrtc = 2040;
@@ -965,7 +952,6 @@ static int neo_init(int force, int par1, int par2)
     __svgalib_banked_mem_size=0x10000;
     __svgalib_linear_mem_base=neo_linear_base;
     __svgalib_linear_mem_size=neo_memory*0x400;
-    neo_is_linear = FALSE;
 
     return 0;
 }
