@@ -169,16 +169,14 @@ static void oak_getmodeinfo(int mode, vga_modeinfo * modeinfo)
 	modeinfo->flags |= IS_INTERLACED;
     }
     if ((oak_chiptype == 87) & (OTI87_OK_LINEAR == 1)) {
-	modeinfo->flags |= CAPABLE_LINEAR;
-	modeinfo->flags |= EXT_INFO_AVAILABLE;
-	modeinfo->chiptype = 87;
-	modeinfo->aperture_size = oak_memorydetect();
-	modeinfo->set_aperture_page = oak_setpage;
-	if (oak_inlinearmode()) {
-	    modeinfo->flags |= IS_LINEAR | LINEAR_MODE;
-	    /* The following line was missing? */
-	    modeinfo->linear_aperture = linearframebuffer;
-	}
+		modeinfo->flags |= CAPABLE_LINEAR;
+		modeinfo->flags |= EXT_INFO_AVAILABLE;
+		modeinfo->chiptype = 87;
+		modeinfo->aperture_size = oak_memorydetect();
+		modeinfo->set_aperture_page = oak_setpage;
+		if (oak_inlinearmode()) {
+			modeinfo->linear_aperture = linearframebuffer;
+		}
     }
 }
 
@@ -675,7 +673,6 @@ static void oak_setlinearmode(void)
     OAKSetByte(OTI87_VIDMAP, temp1);
     linearframebuffer=LINEAR_POINTER;
     VGAMemory_Save = __svgalib_graph_mem;
-    __svgalib_modeinfo_linearset |= IS_LINEAR;
 }
 
 /* oak_clearlinearmode()                        Stop linear mode for OTI-087
@@ -687,7 +684,6 @@ static void oak_setlinearmode(void)
 static void oak_clearlinearmode(void)
 {
     OAKSetByte(OTI87_VIDMAP, 0x00);
-    __svgalib_modeinfo_linearset ^= IS_LINEAR;
     __svgalib_graph_mem = VGAMemory_Save;
     graph_mem = VGAMemory_Save;
 
