@@ -1512,7 +1512,8 @@ static int r128_init(int force, int par1, int par2)
         ((id>>8)==0x5b) ||
         ((id>>8)==0x5c) ||
         ((id>>8)==0x5d) ||
-        ((id>>8)==0x5e)
+        ((id>>8)==0x5e) ||
+        ((id>>8)==0x71)
 		) chiptype = Radeon;
 
 	if( (id == 0x4158) ||
@@ -1682,11 +1683,14 @@ static int r128_init(int force, int par1, int par2)
 			case PCI_CHIP_RV410_5653:
 				IsMobility = TRUE;
 			case PCI_CHIP_RV410_5E48:
-			case PCI_CHIP_RV410_5E4B:
+			case 0x5E49:
 			case PCI_CHIP_RV410_5E4A:
-			case PCI_CHIP_RV410_5E4D:
+			case PCI_CHIP_RV410_5E4B:
 			case PCI_CHIP_RV410_5E4C:
+			case PCI_CHIP_RV410_5E4D:
 			case PCI_CHIP_RV410_5E4F:
+			case 0x5E6B:
+			case 0x5E6D:
 				ChipFamily = CHIP_FAMILY_R420; /* CHIP_FAMILY_RV410*/
 				break;
 				
@@ -1736,6 +1740,8 @@ static int r128_init(int force, int par1, int par2)
 			case PCI_CHIP_R481_4B4A:
 			case PCI_CHIP_R481_4B49:
 			case PCI_CHIP_R481_4B4C:
+			case 0x7105:
+			case 0x7109:
 				ChipFamily = CHIP_FAMILY_R420; /*CHIP_FAMILY_R480*/
 				break;
 				
