@@ -80,7 +80,7 @@
     do {                           \
 	uint32_t tmp = INREG(addr);  \
 	tmp &= (mask);             \
-	tmp |= (val);              \
+	tmp |= ((val) & ~(mask));              \
 	OUTREG(addr, tmp);         \
     } while (0)
 
@@ -88,7 +88,7 @@
 
 #define OUTPLL(addr, val)                                                 \
     do {                                                                  \
-	OUTREG8(R128_CLOCK_CNTL_INDEX, ((addr) & 0x1f) | R128_PLL_WR_EN); \
+	OUTREG8(R128_CLOCK_CNTL_INDEX, ((addr) & 0x3f) | R128_PLL_WR_EN); \
 	OUTREG(R128_CLOCK_CNTL_DATA, val);                                \
     } while (0)
 
@@ -96,7 +96,7 @@
     do {                                                                  \
 	uint32_t tmp = INPLL(addr);                                  \
 	tmp &= (mask);                                                    \
-	tmp |= (val);                                                     \
+	tmp |= ((val) & ~(mask));                                                     \
 	OUTPLL(addr, tmp);                                                \
     } while (0)
 
@@ -1490,8 +1490,10 @@
 #define RADEON_DAC_EXT_CNTL			 0x0280
 #define RADEON_GRPH_BUF_CNTL			 0x02f0
 #define RADEON_VGA_BUF_CNTL			 0x02f4
+#define RADEON_CRTC_CRNT_FRAME              0x0214
 
 #define RADEON_SURFACE_CNTL			 0x0b00
+#define RADEON_SCLK_CNTL			0x0d
 
 #define RADEON_VCLK_SRC_SEL_MASK		 0x0003
 #define RADEON_VCLK_SRC_SEL_CPUCLK		 0x0000
@@ -1501,4 +1503,17 @@
 #define RADEON_BUS_RD_DISCARD_EN		 (1<<24)
 
 #define RADEON_SURF_TRANSLATION_DIS		 (1<<8)
+
+#define RADEON_CONFIG_CNTL           R128_CONFIG_CNTL
+#define RADEON_CFG_ATI_REV_ID_MASK   (0xf << 16)
+#define RADEON_CFG_ATI_REV_A11       (0   << 16)
+
+#define CHIP_ERRATA_R300_CG (1<<0)
+#define CHIP_ERRATA_PLL_DUMMYREADS (1<<1)
+#define CHIP_ERRATA_PLL_DELAY (1<<2)
+
+#define R300_PPLL_REF_DIV_ACC_SHIFT              18
+#define R300_PPLL_REF_DIV_ACC_MASK               (0x3ff << 18)
+
 #endif
+
