@@ -272,7 +272,7 @@ static int s3_cr59;
 static int s3_cr5A;
 static int s3_linear_opt = 0;
 static int s3_linear_addr = 0;
-static int s3_linear_base = 0;
+static unsigned int s3_linear_base = 0;
 static void s3_linear_enable(void);
 static void s3_linear_disable(void);
 #endif
@@ -404,8 +404,6 @@ static void s3_getmodeinfo(int mode, vga_modeinfo * modeinfo)
 #ifdef S3_LINEAR_SUPPORT
     if (modeinfo->bytesperpixel >= 1) {
     	modeinfo->flags |= CAPABLE_LINEAR;
-    	if (s3_linear_addr)
-	    modeinfo->flags |= IS_LINEAR | LINEAR_MODE;
     }
 #endif
 
@@ -1488,7 +1486,7 @@ static char *s3_process_option(int option, int mode, char **nptr)
     }
     if (option == 3) {		/* "ClockChip" */
 	char *ptr;
-	long freq;
+	int freq;
 	ptr = strtok(NULL, " \t");
 	if (strcasecmp(ptr, "ICD2061A") == 0 ||
 	    strcasecmp(ptr, "DCS2824") == 0)	/* Diamond, compatible to icd2061a */
@@ -1686,10 +1684,10 @@ static int s3_init(int force, int par1, int par2)
 #ifdef S3_LINEAR_SUPPORT
     if (s3_chiptype > S3_805) {
     	int found_pciconfig;
-    	unsigned long pci_conf[64];
+    	unsigned int pci_conf[64];
     	
-    	found_pciconfig = __svgalib_pci_find_vendor_vga(0x5333, pci_conf, 0);
-    	if (!found_pciconfig)
+    	found_pciconfig = __svgalib_pci_find_vendor_vga_pos(0x5333, pci_conf);
+    	if (found_pciconfig)
     	    s3_linear_base = pci_conf[4] & 0xFF800000;
     }
     
