@@ -140,8 +140,8 @@ enum { UNKNOWN, TRIO64, TRIO3D, TRIO3D2X,
 #define TRIO_3D_SERIES(chip)     (chip == TRIO3D)
 #define TRIO_3D_2X_SERIES(chip)  (chip == TRIO3D2X)
 
-static int memory, chipset;
-static int is_linear, linear_base;
+static int memory, chipset, is_linear;
+static unsigned int linear_base;
 static int is_savage;
 static int cr58;
 
@@ -171,9 +171,7 @@ static void getmodeinfo(int mode, vga_modeinfo *modeinfo)
     modeinfo->flags &= ~HAVE_RWPAGE;
 
     if (modeinfo->bytesperpixel >= 1) {
-	if(linear_base)modeinfo->flags |= CAPABLE_LINEAR;
-        if (inlinearmode())
-	    modeinfo->flags |= IS_LINEAR | LINEAR_MODE;
+		if(linear_base)modeinfo->flags |= CAPABLE_LINEAR;
     }
 }
 
@@ -481,8 +479,8 @@ static int modeavailable(int mode)
 /* Local, called by setmode(). */
 #define BASE_FREQ 14.31818
 
-static void savageCalcClock(long freq, int min_m, int min_n1, int max_n1, int min_n2, int max_n2, 
-		long freq_min, long freq_max, unsigned int *mdiv, unsigned int *ndiv, unsigned int *r)
+static void savageCalcClock(int freq, int min_m, int min_n1, int max_n1, int min_n2, int max_n2, 
+		int freq_min, int freq_max, unsigned int *mdiv, unsigned int *ndiv, unsigned int *r)
 {
    double ffreq, ffreq_min, ffreq_max;
    double div, diff, best_diff;
@@ -974,11 +972,11 @@ static int test(void)
 {
     int found;
     int id;
-    unsigned long buf[64];
+    unsigned int buf[64];
     
-    found=__svgalib_pci_find_vendor_vga(VENDOR_ID,buf,0);
+    found=__svgalib_pci_find_vendor_vga_pos(VENDOR_ID,buf);
     id=(buf[0]>>16)&0xffff;
-    if(found)return 0;
+    if(!found)return 0;
     switch(id) {
         case 0x8811:
         case 0x8903:
@@ -1005,9 +1003,7 @@ static int test(void)
 		case 0x8d02:
 		case 0x8d03:
 		case 0x8d04:
-            init(0,0,0);
-            return 1;
-            break;
+            return !init(0,0,0);
         default:
             return 0;
     }
@@ -1099,7 +1095,7 @@ static int findcolor(int rgb) {
 }
 
 static int cursor( int cmd, int p1, int p2, int p3, int p4, void *p5) {
-    unsigned long *b3;
+    unsigned int *b3;
     unsigned char *buf;
     int i, j; 
     unsigned int l1, l2;
@@ -1181,7 +1177,7 @@ static int cursor( int cmd, int p1, int p2, int p3, int p4, void *p5) {
             cursor_colors[p1*2+1].c16=((p4&0xf80000)>>8)|((p4&0xfc00)>>5)|((p4&0xf8)>>3);
             cursor_colors[p1*2+1].c15=((p4&0xf80000)>>9)|((p4&0xf800)>>5)|((p4&0xf8)>>3);
             i=memory*1024-(16-p1)*1024;
-            b3=(unsigned long *)p5;
+            b3=(unsigned int *)p5;
             switch(p2) {
                 case 0:
                     for(j=0;j<32;j++) {
@@ -1252,8 +1248,8 @@ DriverSpecs __svgalib_savage_driverspecs =
 
 static int init(int force, int par1, int par2)
 {
-    unsigned long buf[64];
-    unsigned long mmio_base;
+    unsigned int buf[64];
+    unsigned int mmio_base;
     int found=0, config1;
     int mems[8]={2,4,8,12,16,32,64,2};
     char *chipnames[] = {"Unknown", "Trio64", "Trio 3D", "Trio 3d/2X", "Virge", "Virge VX", 
@@ -1278,7 +1274,7 @@ static int init(int force, int par1, int par2)
 
     };
 
-    found=__svgalib_pci_find_vendor_vga(VENDOR_ID,buf,0);
+    found=__svgalib_pci_find_vendor_vga_pos(VENDOR_ID,buf);
 
     id=(buf[0]>>16)&0xffff;
 
@@ -1399,8 +1395,9 @@ static int init(int force, int par1, int par2)
     }
 
     if (__svgalib_driver_report) {
-	fprintf(stderr,"Using SAVAGE driver, %iKB. Chipset: %s\n",memory, chipnames[chipset]);
+		fprintf(stderr,"Using SAVAGE driver, %iKB. Chipset: %s\n",memory, chipnames[chipset]);
     };
+
     cardspecs = malloc(sizeof(CardSpecs));
     cardspecs->videoMemory = memory;
     cardspecs->maxPixelClock4bpp = 0;	
