@@ -247,7 +247,7 @@ static int tvga8900_saveregs(unsigned char regs[])
     port_out(0x0b, SEQ_I);	/* force old mode regs */
     port_out(port_in(SEQ_D), SEQ_D);	/* by writing */
 
-    /* outw(SEQ_I, 0x820E); */ /* unlock conf. reg */
+    /* port_outw_r(SEQ_I, 0x820E); */ /* unlock conf. reg */
     /* port_out(0x0c, SEQ_I); */ /* save conf. reg */
     /* regs[EXT + 11] = port_in(SEQ_D); */
 
@@ -408,7 +408,7 @@ static void tvga8900_setregs(const unsigned char regs[], int mode)
 	port_out(0x0c, SEQ_I);	/* reg 12               */
 	port_out(reg_0c, SEQ_D);
     }
-    /*      outw(SEQ_I, 0x820e); */ /* unlock conf. reg */
+    /*      port_outw_r(SEQ_I, 0x820e); */ /* unlock conf. reg */
     /*      port_out(0x0c, SEQ_I); */ /* reg 12 */
 
     port_out(0x0d, SEQ_I);	/* new reg 13 */
@@ -554,20 +554,20 @@ static int tvga8900_test(void)
     /* 
      * Check first that we have a Trident card.
      */
-    outb(SEQ_I, 0x0b);
+    port_out_r(SEQ_I, 0x0b);
     save0b = port_in(SEQ_D);
-    outw(SEQ_I, 0x000B);	/* Switch to Old Mode */
+    port_outw_r(SEQ_I, 0x000B);	/* Switch to Old Mode */
     port_in(SEQ_D);			/* Now to New Mode */
-    outb(SEQ_I, 0x0E);
+    port_out_r(SEQ_I, 0x0E);
     origVal = port_in(SEQ_D);
-    outb(SEQ_D, 0x00);
+    port_out_r(SEQ_D, 0x00);
     newVal = port_in(SEQ_D) & 0x0F;
-    outb(SEQ_D, (origVal ^ 0x02));
+    port_out_r(SEQ_D, (origVal ^ 0x02));
 
     if (newVal != 2) {
-	outb(SEQ_D, origVal);
-	outb(SEQ_I, 0x0b);
-	outb(SEQ_D, save0b);
+	port_out_r(SEQ_D, origVal);
+	port_out_r(SEQ_I, 0x0b);
+	port_out_r(SEQ_D, save0b);
 	return 0;
     }
 
@@ -598,41 +598,41 @@ static void tvga8900_setpage(int page)
 static void tvga8900_setdisplaystart(int address)
 {
     if (__svgalib_cur_mode == G320x200x256) {
-	outw(CRT_IC, 0x0d + (address & 0x00ff) * 256);
-	outw(CRT_IC, 0x0c + (address & 0xff00));
+	port_outw_r(CRT_IC, 0x0d + (address & 0x00ff) * 256);
+	port_outw_r(CRT_IC, 0x0c + (address & 0xff00));
 	address <<= 2;		/* Adjust address so that extended bits */
 	/* are correctly set later (too allow for */
 	/* multi-page flipping in 320x200). */
 	goto setextendedbits;
     }
     if (tvga8900_memory == 1024) {
-	outw(CRT_IC, 0x0d + ((address >> 3) & 0x00ff) * 256);	/* sa2-sa9 */
-	outw(CRT_IC, 0x0c + ((address >> 3) & 0xff00));	/* sa10-sa17 */
+	port_outw_r(CRT_IC, 0x0d + ((address >> 3) & 0x00ff) * 256);	/* sa2-sa9 */
+	port_outw_r(CRT_IC, 0x0c + ((address >> 3) & 0xff00));	/* sa10-sa17 */
     } else {
-	outw(CRT_IC, 0x0d + ((address >> 2) & 0x00ff) * 256);	/* sa2-sa9 */
-	outw(CRT_IC, 0x0c + ((address >> 2) & 0xff00));	/* sa10-sa17 */
+	port_outw_r(CRT_IC, 0x0d + ((address >> 2) & 0x00ff) * 256);	/* sa2-sa9 */
+	port_outw_r(CRT_IC, 0x0c + ((address >> 2) & 0xff00));	/* sa10-sa17 */
     }
     if (__svgalib_cur_mode != G320x200x256) {
 	port_in(0x3da);		/* set ATC to addressing mode */
-	outb(ATT_IW, 0x13 + 0x20);	/* select ATC reg 0x13 */
+	port_out_r(ATT_IW, 0x13 + 0x20);	/* select ATC reg 0x13 */
 	if (tvga8900_memory == 1024) {
-	    outb(ATT_IW, (port_in(ATT_R) & 0xf0) | (address & 7));
+	    port_out_r(ATT_IW, (port_in(ATT_R) & 0xf0) | (address & 7));
 	    /* write sa0-2 to bits 0-2 */
 	    address >>= 1;
 	} else
-	    outb(ATT_IW, (port_in(ATT_R) & 0xf0) | ((address & 3) << 1));
+	    port_out_r(ATT_IW, (port_in(ATT_R) & 0xf0) | ((address & 3) << 1));
 	/* write sa0-1 to bits 1-2 */
     }
   setextendedbits:
-    outb(CRT_IC, 0x1e);
-    outb(CRT_DC, (port_in(CRT_DC) & 0x5f) | 0x80	/* set bit 7 */
+    port_out_r(CRT_IC, 0x1e);
+    port_out_r(CRT_DC, (port_in(CRT_DC) & 0x5f) | 0x80	/* set bit 7 */
 	 | ((address & 0x40000) >> 13));	/* sa18: write to bit 5 */
-    outb(SEQ_I, 0x0b);
-    outb(SEQ_D, 0);		/* select 'old mode' */
-    outb(SEQ_I, 0x0e);
-    outb(SEQ_D, (port_in(SEQ_D) & 0xfe)
+    port_out_r(SEQ_I, 0x0b);
+    port_out_r(SEQ_D, 0);		/* select 'old mode' */
+    port_out_r(SEQ_I, 0x0e);
+    port_out_r(SEQ_D, (port_in(SEQ_D) & 0xfe)
 	 | ((address & 0x80000) >> 19));	/* sa19: write to bit 0 */
-    outb(SEQ_I, 0x0b);
+    port_out_r(SEQ_I, 0x0b);
     port_in(SEQ_D);			/* return to 'new mode' */
 }
 
@@ -642,7 +642,7 @@ static void tvga8900_setdisplaystart(int address)
 
 static void tvga8900_setlogicalwidth(int width)
 {
-    outw(CRT_IC, 0x13 + (width >> 3) * 256);	/* lw3-lw11 */
+    port_outw_r(CRT_IC, 0x13 + (width >> 3) * 256);	/* lw3-lw11 */
 }
 
 
@@ -718,7 +718,7 @@ bit 0:		force noninterlaced if set
 	tvga8900_nonint = port_in(SEQ_D) & 0x04;
 
 	/* check version */
-	outw(SEQ_I, 0x000b);
+	port_outw_r(SEQ_I, 0x000b);
 	switch (port_in(SEQ_D)) {
 	case 0x02:			/* 8800cs */
 	case 0x03:			/* 8900b */
