@@ -134,7 +134,7 @@ static int joystick_flp0(int joydev, int acquire) {
     unsigned long tmpl;
 
 #ifdef DEBUG
-    printf("joyflp: %d, %d\n", joydev, acquire);
+    fprintf(stderr,"joyflp: %d, %d\n", joydev, acquire);
 #endif
 
     if (!acquire) {
@@ -145,7 +145,7 @@ static int joystick_flp0(int joydev, int acquire) {
 	}
     } else if (joydesc[joydev].fd < 0) {
 #ifdef DEBUG
-    puts("trying to reopen");
+    fprintf("trying to reopen\n");
 #endif
 	/* (re)open joystick device */
    	if ((joydesc[joydev].fd = open(__joystick_devicenames[joydev] ?
@@ -223,17 +223,17 @@ static int jscal0(int joydev, __joystick_output jo)
    
    if (-1 == ioctl(joydesc[joydev].fd, JS_SET_TIMELIMIT, &tmpl)) {
 	if (__svgalib_driver_report)
-	    printf("svgalib, joystick%d: Failed to set timelimit\n", joydev);
+	    fprintf(stderr,"svgalib, joystick%d: Failed to set timelimit\n", joydev);
 	return -1;
    }
    
    if (-1 == ioctl(joydesc[joydev].fd, JS_GET_CAL, &js_data)) {
 	if (__svgalib_driver_report)
-	    printf("svgalib, joystick%d: Failed to read calibration data\n", joydev);
+	    fprintf(stderr,"svgalib, joystick%d: Failed to read calibration data\n", joydev);
 	return -1;
    }
    if (__svgalib_driver_report)
-	printf("svgalib, joystick%d: Current correction: %d , %d\n", joydev,
+	fprintf(stderr,"svgalib, joystick%d: Current correction: %d , %d\n", joydev,
 		js_data.x, js_data.y);
 
    sprintf(msg, "Move Joystick %d to lower right corner and press either button...\n", joydev);
@@ -248,13 +248,13 @@ static int jscal0(int joydev, __joystick_output jo)
    js_data.y = tmp;
 
    if (__svgalib_driver_report)
-	printf("svgalib, joystick%d: Setting correction: %d , %d\n", joydev,
+	fprintf(stderr,"svgalib, joystick%d: Setting correction: %d , %d\n", joydev,
 		js_data.x, js_data.y);
    
    if (-1 == ioctl(joydesc[joydev].fd, JS_SET_CAL, &js_data))
      {
 	if (__svgalib_driver_report)
-	    printf("svgalib, joystick%d: Failed to set calibration data\n", joydev);
+	    fprintf(stderr,"svgalib, joystick%d: Failed to set calibration data\n", joydev);
 	return -1;
      }
 
@@ -266,7 +266,7 @@ static int jscal0(int joydev, __joystick_output jo)
    while ((read (joydesc[joydev].fd, &js_data, JS_RETURN) > 0) && !js_data.buttons)
      usleep(100);
    if (__svgalib_driver_report)
-	printf("svgalib, joystick%d: Setting center offset: %d , %d\n", 
+	fprintf(stderr,"svgalib, joystick%d: Setting center offset: %d , %d\n", 
 	       joydev,	js_data.x, js_data.y);
    joydesc[joydev].joydata->p.prot0.xdif = js_data.x;
    joydesc[joydev].joydata->p.prot0.ydif = js_data.y;
@@ -338,7 +338,7 @@ static int jscal1(int joydev, __joystick_output jo)
    if (-1 == ioctl(joydesc[joydev].fd, JSIOCGCORR, &corr)) 
      {
 	if (__svgalib_driver_report)
-	   printf("svgalib, joystick %d: error getting correction\n", joydev);
+	   fprintf(stderr,"svgalib, joystick %d: error getting correction\n", joydev);
 	return -1;
      }
 
@@ -357,12 +357,12 @@ static int jscal1(int joydev, __joystick_output jo)
    
    
    if (__svgalib_driver_report)
-     printf("svgalib, joystick %d: Setting correction to: %s\n", joydev, corr_name[JS_CORR_NONE]);
+     fprintf(stderr,"svgalib, joystick %d: Setting correction to: %s\n", joydev, corr_name[JS_CORR_NONE]);
    
    if (-1 == ioctl(joydesc[joydev].fd, JSIOCSCORR, &corr)) 
      {
    	if (__svgalib_driver_report)
-	  printf("svgalib, joystick %d: error setting correction\n", joydev);
+	  fprintf(stderr,"svgalib, joystick %d: error setting correction\n", joydev);
 	return -1;
      }
    
@@ -434,25 +434,25 @@ static int jscal1(int joydev, __joystick_output jo)
 
    if (__svgalib_driver_report)
      {
-	printf("svgalib, joystick %d: Setting correction to: %s\n", joydev,
+	fprintf(stderr,"svgalib, joystick %d: Setting correction to: %s\n", joydev,
 		 corr_name[(int)corr[0].type]);
 	for (i = 0; i < joydesc[joydev].joydata->axes; i++) 
 	  {
-	     printf("  Coefs for axis %d:", i);
+	     fprintf(stderr,"  Coefs for axis %d:", i);
 	     for(j = 0; j < corr_coef_num[(int)corr[i].type]; j++) 
 	       {
-		  printf(" %d", corr[i].coef[j]); 
-		  if (j < corr_coef_num[(int)corr[i].type] - 1) putchar(',');
+		  fprintf(stderr," %d", corr[i].coef[j]); 
+		  if (j < corr_coef_num[(int)corr[i].type] - 1) putc(',',stderr);
 	       }
-	     puts("");
+	     fprintf(stderr,"\n");
 	  }
-	puts("");
+	fprintf(stderr,"\n");
      }
    
    if (-1 == ioctl(joydesc[joydev].fd, JSIOCSCORR, &corr)) 
      {
    	if (__svgalib_driver_report)
-	  printf("svgalib, joystick %d: error setting correction\n", joydev);
+	  fprintf(stderr,"svgalib, joystick %d: error setting correction\n", joydev);
 	return -1;
      }
    
@@ -482,7 +482,7 @@ void __joystick_flip_vc(int acquire) {
    for (i = 0; i < NUM_JOYSTICKS; i++)
 	if (joydesc[i].joydata && joydesc[i].joydata->flip_vc)
 	    if (joydesc[i].joydata->flip_vc(i, acquire)) {
-		puts("svgalib: Fatal, cannot reopen joystick after VC switch.\n");
+		fprintf(stderr,"svgalib: Fatal, cannot reopen joystick after VC switch.\n");
 		exit(1);
 	    }
 }
@@ -515,7 +515,7 @@ int joystick_init(int joydev, __joystick_output jo)
 	if (-1 == ioctl(joydesc[joydev].fd, JSIOCGVERSION, &version)) 
 	  {
 	     if (__svgalib_driver_report)
-	       printf("svgalib: Initializing joystick %d: assuming old 0.x driver protocol\n", joydev);
+	       fprintf(stderr,"svgalib: Initializing joystick %d: assuming old 0.x driver protocol\n", joydev);
 	     
 	     /* Old 0.x protocol */
 	     joystick_initdefhandler(joydev, 4, 2);
@@ -528,7 +528,7 @@ int joystick_init(int joydev, __joystick_output jo)
 	     joydesc[joydev].joydata->p.prot0.ydif = 0x80;
 	     
 	     if (__svgalib_driver_report)
-	       printf("   assuming %d axes and %d buttons\n",
+	       fprintf(stderr,"   assuming %d axes and %d buttons\n",
 		      joydesc[joydev].joydata->axes, joydesc[joydev].joydata->buttons);
 	     
 	     /* Now calibrate ... */
@@ -538,7 +538,7 @@ int joystick_init(int joydev, __joystick_output jo)
 	     if (-1 == ioctl(joydesc[joydev].fd, JS_GET_CAL,
 			 &joydesc[joydev].joydata->p.prot0.caldata)) {
 	       if (__svgalib_driver_report)
-		  printf("svgalib, joystick%d: Failed to read calibration data\n", joydev);
+		  fprintf(stderr,"svgalib, joystick %d: Failed to read calibration data\n", joydev);
 	       joystick_close(joydev);
 	       return -1;
 	     }
@@ -549,7 +549,7 @@ int joystick_init(int joydev, __joystick_output jo)
 	     char axes, buttons;
 
 	     if (__svgalib_driver_report)
-	       printf("svgalib: Initializing joystick %d: driver version %x.%x.%x (new protocol)\n",
+	       fprintf(stderr,"svgalib: Initializing joystick %d: driver version %x.%x.%x (new protocol)\n",
 		      joydev,
 		      (version & 0xff0000) >> 16, (version & 0xff00)>> 8,
 		      version & 0xff);
@@ -557,7 +557,7 @@ int joystick_init(int joydev, __joystick_output jo)
 	     if (-1 == ioctl(joydesc[joydev].fd, JSIOCGAXES, &axes)) 
 	       {
 	          if (__svgalib_driver_report)
-		    printf("svgalib, joystick%d: error getting number of axes\n", joydev);
+		    fprintf(stderr,"svgalib, joystick %d: error getting number of axes\n", joydev);
 	          joystick_close(joydev);
 		  return -1;
 	       }
@@ -565,13 +565,13 @@ int joystick_init(int joydev, __joystick_output jo)
 	     if (-1 == ioctl(joydesc[joydev].fd, JSIOCGBUTTONS, &buttons)) 
 	       {
 	          if (__svgalib_driver_report)
-		    printf("svgalib, joystick%d: error getting number of buttons\n", joydev);
+		    fprintf(stderr, "svgalib, joystick %d: error getting number of buttons\n", joydev);
 	          joystick_close(joydev);
 		  return -1;
 	       }
 
 	     if (__svgalib_driver_report)
-	       printf("joystick %d has %d axes and %d buttons\n", joydev, axes, buttons);
+	       fprintf(stderr,"joystick %d has %d axes and %d buttons\n", joydev, axes, buttons);
 	     joystick_initdefhandler(joydev, buttons, axes);
 	     
 	     /* Now calibrate ... */
@@ -582,7 +582,7 @@ int joystick_init(int joydev, __joystick_output jo)
 	     if (-1 == ioctl(joydesc[joydev].fd, JSIOCGCORR,
 			&joydesc[joydev].joydata->p.prot1.corrdata)) {
 	       if (__svgalib_driver_report)
-		  printf("svgalib, joystick%d: Failed to read calibration data\n", joydev);
+		  fprintf(stderr,"svgalib, joystick%d: Failed to read calibration data\n", joydev);
 	       joystick_close(joydev);
 	       return -1;
 	     }
@@ -636,7 +636,7 @@ static void joystick_initdefhandler(int joydev, int buttons, int axes)
    joydesc[joydev].joydata = malloc(sizeof(joydat_t));
    if (!joydesc[joydev].joydata) {
      nomem:
-	printf("svgalib: Fatal, out of memory\n");
+	fprintf(stderr,"svgalib: Fatal, out of memory\n");
 	exit(1);
    }
    joydesc[joydev].joydata->axes = axes;
@@ -658,7 +658,7 @@ static void joystick_initdefhandler(int joydev, int buttons, int axes)
 static void joystick_defaulthandler(int event, int num, char val, int joydev)
 {
 #ifdef DEBUG
-   printf("%d: %d %d %d\n", joydev, event, num, val);
+   fprintf(stderr,"%d: %d %d %d\n", joydev, event, num, val);
 #endif
    switch (event)
      {
