@@ -590,7 +590,7 @@ static int keyboard_getevents(int wait)
 	if (ctrl_state && c_state && !(translatemode & DONT_CATCH_CTRLC))
 	    raise(SIGINT);
 	if (((alt_state && functionkey_state)||(win_state && functionkey_state)) &&
-             !__svgalib_novccontrol){
+			!__svgalib_novccontrol && !(translatemode & DONT_CATCH_ALT_Fx)){
 	    /* VT switch. */
 	    /* *** what about F11 & F12? */
 	    int j, vt = 0;
@@ -731,7 +731,7 @@ int keyboard_keypressed(int scancode)
 char *
  keyboard_getstate(void)
 {
-    return state;
+    return (char *)state;
 }
 
 void keyboard_translatekeys(int mode)
@@ -784,7 +784,7 @@ static char *kbd_load_keymap(char *ptr)
         usekeymap = 0;
 
         /* Initialize keymap */
-        for (i = 0; i < NR_KEYS; keymap[i++] = i);
+        for (i = 0; i < NR_KEYS; keymap[i] = i, i++);
 
         while(!feof(keymapfile)) {
             /* Read */
