@@ -44,7 +44,7 @@ static int    m_fdmode = 0;		/* 0 means don't wait (NDELAY) */
 static int    m_modem_ctl = 0;
 
 /* Settings found on mouse open.. Probably std termios should be restored as well */
-static unsigned long m_old_modem_info;	/*  original state of DTR/RTS */
+static int  m_old_modem_info;		/*  original state of DTR/RTS */
 static char m_modem_info_valid = 0;	/*  ==0 means: couldn't get it: old kernel? */
 
 unsigned char __svgalib_m_ignore_dx = 0; /* These are flags set by keyboard.c */
@@ -180,7 +180,7 @@ static char* mouse_process_option(int option, int mode, char **nptr) {
  int newmtype;
 
 #ifdef DEBUG_ACCEL
-  fprintf(stderr,"Processing option %ld (%s)\n", (long)option, mouse_config_options[option]);
+  fprintf(stderr,"Processing option %d (%s)\n", option, mouse_config_options[option]);
 #endif
 
    switch (option) {
@@ -349,12 +349,12 @@ static int ms_init(void)
     __svgalib_read_options(mouse_config_options, mouse_process_option);
 
     if (m_maxdelta < 0  &&  !m_force) {
-      fprintf(stderr, "svgalib: mouse_maxdelta value '%ld' is invalid, should be > 0\n", (long)m_maxdelta);
+      fprintf(stderr, "svgalib: mouse_maxdelta value '%d' is invalid, should be > 0\n", m_maxdelta);
       m_maxdelta = DEFAULT_MAXDELTA;
     }
 
     if (m_accel_maxdelta < 0  &&  !m_force) {
-      fprintf(stderr, "svgalib: mouse_accel_maxdelta value '%ld' is invalid, should be > 0\n", (long)m_accel_maxdelta);
+      fprintf(stderr, "svgalib: mouse_accel_maxdelta value '%d' is invalid, should be > 0\n", m_accel_maxdelta);
       m_accel_maxdelta = DEFAULT_ACCEL_MAXDELTA;
     }
 
@@ -377,7 +377,7 @@ static int ms_init(void)
 
       if (!m_force) {
          if (m_accel_thresh <= 0  ||  m_accel_thresh > 200) {
-            fprintf(stderr, "svgalib: mouse_accel_thresh value '%ld' is invalid, should be between 0 and 200\n", (long)m_accel_thresh);
+            fprintf(stderr, "svgalib: mouse_accel_thresh value '%d' is invalid, should be between 0 and 200\n", m_accel_thresh);
 	    m_accel_thresh = DEFAULT_ACCEL_THRESH;
          }
       } else if (m_accel_thresh < 0) {
@@ -404,7 +404,7 @@ static int ms_init(void)
               * (m_accel_mult - m_accel_offset) + m_accel_offset;
 
 #ifdef DEBUG_ACCEL
-	    fprintf(stderr,"  %ld => %f (%f)\n", (long)i, (double)m_accel_powertable[i] * i,
+	    fprintf(stderr,"  %d => %f (%f)\n", i, (double)m_accel_powertable[i] * i,
 	  			     (double)m_accel_powertable[i]);
 #endif
           }
@@ -413,22 +413,31 @@ static int ms_init(void)
     }
 
 #ifdef DEBUG_ACCEL
-    fprintf(stderr,"m_accel_type: %ld\n",	(long)m_accel_type);
-    fprintf(stderr,"m_force: %ld\n",		(long)m_force);
-    fprintf(stderr,"m_accel_thresh: %ld\n",	(long)m_accel_thresh);
-    fprintf(stderr,"m_accel_offset: %ld\n",	(long)m_accel_offset);
+    fprintf(stderr,"m_accel_type: %d\n",	(int)m_accel_type);
+    fprintf(stderr,"m_force: %d\n",		m_force);
+    fprintf(stderr,"m_accel_thresh: %d\n",	m_accel_thresh);
+    fprintf(stderr,"m_accel_offset: %d\n",	(int)m_accel_offset);
     fprintf(stderr,"m_accel_mult: %f\n",	(double)m_accel_mult);
     fprintf(stderr,"m_accel_power: %f\n",	(double)m_accel_power);
-    fprintf(stderr,"m_maxdelta: %ld\n",		(long)m_maxdelta);
-    fprintf(stderr,"m_accel_maxdelta: %ld\n",	(long)m_accel_maxdelta);
+    fprintf(stderr,"m_maxdelta: %d\n",		m_maxdelta);
+    fprintf(stderr,"m_accel_maxdelta: %d\n",	m_accel_maxdelta);
 #endif
 
     /*  Ensure that the open will get a file descriptor greater
      *  than 2, else problems can occur with stdio functions
      *  under certain strange conditions:  */
-    if (fcntl(0,F_GETFD) < 0) open("/dev/null", O_RDONLY);
-    if (fcntl(1,F_GETFD) < 0) open("/dev/null", O_WRONLY);
-    if (fcntl(2,F_GETFD) < 0) open("/dev/null", O_WRONLY);
+    if ((fcntl(0,F_GETFD) == -1) && (open("/dev/null", O_RDONLY) == -1) ) {
+        perror("/dev/null");
+        exit(1);
+    }
+    if ((fcntl(1,F_GETFD) == -1) && (open("/dev/null", O_WRONLY) == -1) ) {   
+        perror("/dev/null");
+        exit(1);  
+    }
+    if ((fcntl(2,F_GETFD) == -1) && (open("/dev/null", O_WRONLY) == -1) ) {
+        perror("/dev/null");
+        exit(1);
+    }
 
     /* Set the proper wheel delta */
     if(m_wheel_steps)
@@ -458,7 +467,7 @@ static int ms_init(void)
 				   TIOCMGET, &m_old_modem_info);
 
 	if (m_modem_info_valid) {
-	    unsigned long param = m_old_modem_info;
+	    int param = m_old_modem_info;
 
 	    /* Prepare new stat: */
 
@@ -1172,20 +1181,20 @@ static int get_ms_event(int wait) {
 
       case MOUSE_ACCEL_TYPE_NORMAL:
 #ifdef DEBUG_ACCEL 
-  fprintf(stderr,"%ld\t", (long)dx);
+  fprintf(stderr,"%d\t", dx);
 #endif
 	if (abs(dx) > m_accel_thresh) dx = (int) ((float)dx * m_accel_mult);
 	if (abs(dy) > m_accel_thresh) dy = (int) ((float)dy * m_accel_mult);
 	if (abs(dz) > m_accel_thresh) dz = (int) ((float)dz * m_accel_mult);
 #ifdef DEBUG_ACCEL
-  fprintf(stderr,"%ld\n", (long)dx);
+  fprintf(stderr,"%d\n", dx);
 #endif
         break;
 
 
       case MOUSE_ACCEL_TYPE_POWER:
 #ifdef DEBUG_ACCEL 
-  fprintf(stderr,"%ld\t", (long)dx);
+  fprintf(stderr,"%d\t", dx);
 #endif
 	delta = abs(dx);
 	dx = (delta >= m_accel_thresh)  ?  (float)dx * m_accel_mult :
@@ -1200,7 +1209,7 @@ static int get_ms_event(int wait) {
 	     (float)dz * m_accel_powertable[delta];
 
 #ifdef DEBUG_ACCEL
-  fprintf(stderr,"%ld\n", (long)dx);
+  fprintf(stderr,"%d\n", dx);
 #endif
         break;
     }
