@@ -1,9 +1,9 @@
 /*
 
-    3DKIT   version   1.2
+    3DKIT   version   1.3
     High speed 3D graphics and rendering library for Linux.
 
-    1996  Paul Sheer   psheer@hertz.mech.wits.ac.za
+    1996  Paul Sheer   psheer@icon.co.za
 
     This file is an example program demonstrating the use of the
     3dkit library. It is not part of the library and is not copyright.
