@@ -23,7 +23,7 @@ void gl_swtriangle (int x0, int y0, int xd0, int yd0, \
 
 void gl_striangle (int x0, int y0, int x1, int y1, int x2, int y2, int color, int bf);
 
-void gl_trisetcolorlookup (int i, long c);
-long gl_trigetcolorlookup (int i);
+void gl_trisetcolorlookup (int i, int c);
+int  gl_trigetcolorlookup (int i);
 
 void gl_trisetdrawpoint (void (setpixelfunc) (int, int, int));
