@@ -74,19 +74,19 @@ main (int argc, char *argv[])
 #endif
       printf ("	-r	Switch to 8 line characters again (350 line frame, 70 Hz).\n");
       printf ("LINES environment variable is used to detect 43 or 44 line console.\n");
-      exit (0);
+      return 0;
     }
 
   if (argv[1][0] != '-')
     {
       printf ("Must specify -f, -v or -r.\n");
-      exit (1);
+      return 1;
     }
 
   if (argv[1][1] != 'f' && argv[1][1] != 'v' && argv[1][1] != 'w' && argv[1][1] != 'r')
     {
       printf ("Must specify -f, -v, or -r.\n");
-      exit (1);
+      return 1;
     }
 
   lines = atoi (getenv ("LINES"));
@@ -195,7 +195,7 @@ main (int argc, char *argv[])
     }
 #endif
 
-  exit (0);
+  return 0;
 }
 
 
